@@ -118,6 +118,24 @@ SKGObjectModel::SKGObjectModel(SKGDocumentBank* iDocument,
                 doubleColumn.schema="d_date;i_NBRECURRENT;t_bookmarked;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_REALCOMMENT;t_CATEGORY;t_REALCATEGORY;"
                                     "t_status;f_REALCURRENTAMOUNT_EXPENSE;f_REALCURRENTAMOUNT_INCOME;f_CURRENTAMOUNT_EXPENSE;f_CURRENTAMOUNT_INCOME";
                 listSchema.push_back(doubleColumn);
+        } else if (getRealTable()=="recurrentoperation") {
+                listSchema.clear();
+
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=tr("Default");
+                def.icon="edit-undo";
+                def.schema="d_DUEDATE;d_date;t_PERIODNLS;i_auto_write_days;i_warn_days;t_ACCOUNT;i_number;t_mode;t_payee;t_comment;t_CATEGORY;"
+                           "t_status;f_CURRENTAMOUNT";
+                listSchema.push_back(def);
+
+                SKGModelTemplate minimun;
+                minimun.id="minimun";
+                minimun.name=tr("Minimun");
+                minimun.icon="";
+                minimun.schema="d_DUEDATE;d_date;t_PERIODNLS;i_auto_write_days;i_warn_days;t_ACCOUNT;t_payee;;"
+                               "t_status;f_CURRENTAMOUNT";
+                listSchema.push_back(minimun);
         } else if (getRealTable()=="account") {
                 SKGModelTemplate minimun;
                 minimun.id="minimun";
@@ -291,7 +309,7 @@ QVariant SKGObjectModel::data(const QModelIndex &index, int role) const
                         QString t_icon=obj->getAttribute("t_icon");
                         if (t_icon.isEmpty()) t_icon=obj->getAttribute("t_ICON");
                         if (!t_icon.isEmpty()) {
-                                QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")+KGlobal::locale()->language()+'/'));
+                                QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                                 return qVariantFromValue(QIcon(dirLogo.absoluteFilePath(t_icon)));
                         }
                 } else if (getRealTable()=="category" && index.column() == 0) {
@@ -349,24 +367,26 @@ QVariant SKGObjectModel::data(const QModelIndex &index, int role) const
         case Qt::CheckStateRole: {
                 //CheckState
                 SKGObjectBase* obj = getObjectPointer(index);
-                QString att=listAttibutes[index.column()];
-                if (operationTable && att=="t_status") {
-                        QString t_status=obj->getAttribute("t_status");
-                        if (t_status=="P") return Qt::PartiallyChecked;
-                        else if (t_status=="C") return Qt::Checked;
-                        else if (t_status=="N") return Qt::Unchecked;
-                } else if (accountTable && att=="t_close") {
-                        QString t_status=obj->getAttribute("t_close");
-                        if (t_status=="Y") return Qt::Checked;
-                        else return Qt::Unchecked;
-                } else  if (recurrentoperationTable && att=="i_auto_write_days") {
-                        QString t_auto_write=obj->getAttribute("t_auto_write");
-                        if (t_auto_write=="Y") return Qt::Checked;
-                        else return Qt::Unchecked;
-                } else  if (recurrentoperationTable && att=="i_warn_days") {
-                        QString t_auto_write=obj->getAttribute("t_warn");
-                        if (t_auto_write=="Y") return Qt::Checked;
-                        else return Qt::Unchecked;
+                if (obj) {
+                        QString att=listAttibutes[index.column()];
+                        if (operationTable && att=="t_status") {
+                                QString t_status=obj->getAttribute("t_status");
+                                if (t_status=="P") return Qt::PartiallyChecked;
+                                else if (t_status=="C") return Qt::Checked;
+                                else if (t_status=="N") return Qt::Unchecked;
+                        } else if (accountTable && att=="t_close") {
+                                QString t_status=obj->getAttribute("t_close");
+                                if (t_status=="Y") return Qt::Checked;
+                                else return Qt::Unchecked;
+                        } else  if (recurrentoperationTable && att=="i_auto_write_days") {
+                                QString t_auto_write=obj->getAttribute("t_auto_write");
+                                if (t_auto_write=="Y") return Qt::Checked;
+                                else return Qt::Unchecked;
+                        } else  if (recurrentoperationTable && att=="i_warn_days") {
+                                QString t_auto_write=obj->getAttribute("t_warn");
+                                if (t_auto_write=="Y") return Qt::Checked;
+                                else return Qt::Unchecked;
+                        }
                 }
                 break;
         }
@@ -378,25 +398,26 @@ QVariant SKGObjectModel::data(const QModelIndex &index, int role) const
                         if (getAttributeType(index.column())==SKGObjectModelBase::DOUBLE && att!="f_QUANTITY" && att!="f_REALQUANTITY") {
                                 QString toolTipString;
                                 SKGObjectBase* obj = getObjectPointer(index);
+                                if (obj) {
+                                        //Add secondary unit
+                                        double val=SKGServices::stringToDouble(obj->getAttribute(att));
+                                        double unitval=((SKGDocumentBank*) getDocument())->getSecondaryUnitValue();
+                                        if (unitval)  toolTipString=KGlobal::locale()->formatMoney (val/unitval, secondaryUnit, 2);
 
-                                //Add secondary unit
-                                double val=SKGServices::stringToDouble(obj->getAttribute(att));
-                                double unitval=((SKGDocumentBank*) getDocument())->getSecondaryUnitValue();
-                                if (unitval)  toolTipString=KGlobal::locale()->formatMoney (val/unitval, secondaryUnit, 2);
+                                        //Add original amount
+                                        QString originalAmount=obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
+                                        if (!originalAmount.isEmpty()) {
+                                                if (!toolTipString.isEmpty()) toolTipString+="\n\n";
+                                                double val1=SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
+                                                double val2=SKGServices::stringToDouble(originalAmount);
+                                                double gain=(val2!=0 ? 100.0*(val1-val2)/val2 : 0);
+                                                toolTipString+=i18n("Original amount=%1 (%2 %)",
+                                                                    KGlobal::locale()->formatMoney (val2, ((SKGDocumentBank*) getDocument())->getPrimaryUnit(), 2),
+                                                                    gain);
+                                        }
 
-                                //Add original amount
-                                QString originalAmount=obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
-                                if (!originalAmount.isEmpty()) {
-                                        if (!toolTipString.isEmpty()) toolTipString+="\n\n";
-                                        double val1=SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
-                                        double val2=SKGServices::stringToDouble(originalAmount);
-                                        double gain=(val2!=0 ? 100.0*(val1-val2)/val2 : 0);
-                                        toolTipString+=i18n("Original amount=%1 (%2 %)",
-                                                            KGlobal::locale()->formatMoney (val2, ((SKGDocumentBank*) getDocument())->getPrimaryUnit(), 2),
-                                                            gain);
+                                        if (!toolTipString.isEmpty()) return toolTipString;
                                 }
-
-                                if (!toolTipString.isEmpty()) return toolTipString;
                         }
                 }
                 break;
@@ -438,15 +459,17 @@ bool SKGObjectModel::setData(const QModelIndex & index, const QVariant& value, i
 
                         //Get the real object, not the object from the view
                         SKGObjectBase* objtmp=getObjectPointer(index);
-                        SKGRecurrentOperationObject obj=SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
+                        if (objtmp) {
+                                SKGRecurrentOperationObject obj=SKGRecurrentOperationObject(objtmp->getDocument(), objtmp->getID());
 
-                        SKGBEGINTRANSACTION(*getDocument(), i18n("Recurrent operation update"), err);
-                        if (att=="i_warn_days") {
-                                err=obj.warnEnabled(!obj.isWarnEnabled());
-                                if (err.isSucceeded()) obj.save();
-                        } else if (att=="i_auto_write_days") {
-                                err=obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
-                                if (err.isSucceeded()) obj.save();
+                                SKGBEGINTRANSACTION(*getDocument(), i18n("Recurrent operation update"), err);
+                                if (att=="i_warn_days") {
+                                        err=obj.warnEnabled(!obj.isWarnEnabled());
+                                        if (err.isSucceeded()) obj.save();
+                                } else if (att=="i_auto_write_days") {
+                                        err=obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
+                                        if (err.isSucceeded()) obj.save();
+                                }
                         }
                 }
 
@@ -498,7 +521,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData *data,
 {
         if (SKGObjectModelBase::dropMimeData(data, action, row, column, parent)) return true;
         if (action == Qt::IgnoreAction) return true;
-        if (!data->hasFormat("application/skrooge.category.ids")) return false;
+        if (!data || !data->hasFormat("application/skrooge.category.ids")) return false;
         if (column > 0) return false;
 
         QByteArray encodedData = data->data("application/skrooge.category.ids");
