@@ -83,7 +83,8 @@ QString SKGCategoryObject::getFullName() const
 
 SKGError SKGCategoryObject::createPathCategory(const SKGDocumentBank* iDocument,
                 const QString& iFullPath,
-                SKGCategoryObject& oCategory)
+                SKGCategoryObject& oCategory,
+                bool iSendPopupMessageOnCreation)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGCategoryObject::createPathCategory", err);
@@ -128,6 +129,10 @@ SKGError SKGCategoryObject::createPathCategory(const SKGDocumentBank* iDocument,
                                 if (err.isSucceeded()) err = oCategory.save();
                         }
                 }
+
+                if (err.isSucceeded() && iSendPopupMessageOnCreation) {
+                        ((SKGDocumentBank*) iDocument)->sendMessage(tr("Category [%1] has been created").arg(iFullPath), true);
+                }
         }
 
         return err;
