@@ -67,12 +67,14 @@ public:
          * @param iDocument the document where to create
          * @param iFullPath the full path. Example: cat1|cat2|cat3
          * @param oCategory the leaf of the branch
+         * @param iSendPopupMessageOnCreation to send a creation message if the category is created
          * @return an object managing the error.
          *   @see SKGError
          */
         static SKGError createPathCategory(const SKGDocumentBank* iDocument,
                                            const QString& iFullPath,
-                                           SKGCategoryObject& oCategory);
+                                           SKGCategoryObject& oCategory,
+                                           bool iSendPopupMessageOnCreation=false);
 
         /**
          * Set the name of this object
