@@ -69,7 +69,7 @@ QStringList SKGDocumentBank::getImpactedTable(const QString& iTable) const
 
 QString SKGDocumentBank::getViewsIndexesAndTriggersVersion() const
 {
-        return "2009.03.16";
+        return "2009.03.22";
 }
 
 SKGError SKGDocumentBank::refreshViewsIndexesAndTriggers() const
@@ -166,6 +166,8 @@ SKGError SKGDocumentBank::refreshViewsIndexesAndTriggers() const
                 "CREATE UNIQUE INDEX uidx_category_fullname ON  category(t_fullname);;"
                 "DROP INDEX IF EXISTS idx_operation_account_id;;"
                 "CREATE INDEX  idx_operation_account_id ON operation (rd_account_id);;"
+                "DROP INDEX IF EXISTS idx_operation_tmp1_found_transfert;;"
+                "CREATE INDEX  idx_operation_tmp1_found_transfert ON operation (rc_unit_id, d_date);;"
                 "DROP INDEX IF EXISTS idx_operation_grouped_operation_id;;"
                 "CREATE INDEX  idx_operation_grouped_operation_id ON operation (i_group_id);;"
                 "DROP INDEX IF EXISTS idx_operation_t_mode;;"
@@ -182,8 +184,6 @@ SKGError SKGDocumentBank::refreshViewsIndexesAndTriggers() const
                 "CREATE INDEX  idx_operation_t_status ON operation (t_status);;"
                 "DROP INDEX IF EXISTS idx_operation_t_import_id;;"
                 "CREATE INDEX  idx_operation_t_import_id ON operation (t_import_id);;"
-                "DROP INDEX IF EXISTS idx_operation_tmp1_found_transfert;;"
-                "CREATE INDEX  idx_operation_tmp1_found_transfert ON operation (id, rc_unit_id, d_date, rd_account_id);;"
                 "DROP INDEX IF EXISTS idx_suboperation_operation_id;;"
                 "CREATE INDEX idx_suboperation_operation_id ON suboperation (rd_operation_id);;"
                 "DROP INDEX IF EXISTS idx_suboperation_category_id;;"
@@ -243,7 +243,7 @@ SKGError SKGDocumentBank::refreshViewsIndexesAndTriggers() const
                 "SELECT DISTINCT i_number, rd_account_id FROM operation;;"
 
                 "CREATE VIEW  v_operation_next_numbers AS "
-                "SELECT T1.i_number as i_number FROM v_operation_numbers as T1 LEFT OUTER JOIN v_operation_numbers T2 "
+                "SELECT T1.i_number+1 as i_number FROM v_operation_numbers as T1 LEFT OUTER JOIN v_operation_numbers T2 "
                 "ON T2.rd_account_id=T1.rd_account_id AND T2.i_number=T1.i_number+1 "
                 "WHERE T1.i_number!=0 AND (T2.i_number IS NULL) ORDER BY T1.i_number;;"
 
@@ -387,8 +387,8 @@ SKGError SKGDocumentBank::refreshViewsIndexesAndTriggers() const
                 "from v_category_display_tmp;;"
 
                 //recurrentoperation
-                "CREATE VIEW  v_recurrentoperation_display AS SELECT rop.*, op.t_displayname as  t_operationname "
-                "from v_recurrentoperation rop, v_operation_displayname as op WHERE rop.rd_operation_id=op.ID;;"
+                "CREATE VIEW  v_recurrentoperation_display AS SELECT rop.*, op.* "
+                "from v_recurrentoperation rop, v_operation_display as op WHERE rop.rd_operation_id=op.ID;;"
                 ;
 
         err=SKGDocument::refreshViewsIndexesAndTriggers();
