@@ -73,17 +73,19 @@ void SKGCalculatorEdit::setValue (double iValue)
 
 void SKGCalculatorEdit::keyPressEvent( QKeyEvent * event )
 {
-        int key=event->key();
-        if (mode()==CALCULATOR) {
-                bool hasText=!text().isEmpty() && selectedText()!=text();
+        if (event) {
+                int key=event->key();
+                if (mode()==CALCULATOR) {
+                        bool hasText=!text().isEmpty() && selectedText()!=text();
 
-                if (event->count()==1 && ((key==Qt::Key_Plus && hasText) || (key==Qt::Key_Minus && hasText) || key==Qt::Key_Asterisk || key==Qt::Key_Slash || key==Qt::Key_Return)) {
+                        if (event->count()==1 && ((key==Qt::Key_Plus && hasText) || (key==Qt::Key_Minus && hasText) || key==Qt::Key_Asterisk || key==Qt::Key_Slash || key==Qt::Key_Return)) {
+                                keyPressEvent(key);
+                                event->accept();
+                        } else KLineEdit::keyPressEvent(event);
+                } else {
                         keyPressEvent(key);
-                        event->accept();
-                } else KLineEdit::keyPressEvent(event);
-        } else {
-                keyPressEvent(key);
-                KLineEdit::keyPressEvent(event);
+                        KLineEdit::keyPressEvent(event);
+                }
         }
 }
 
