@@ -54,27 +54,27 @@ SKGGraphicsView::SKGGraphicsView(QWidget *parent)
         ui.kGraphicsView->setContextMenuPolicy(Qt::CustomContextMenu);
         connect(ui.kGraphicsView, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
-        menu = new KMenu(ui.kGraphicsView);
-        menu->addTitle(i18n("Graphic"));
+        mainMenu = new KMenu(ui.kGraphicsView);
+        mainMenu->addTitle(i18n("Graphic"));
 
-        QAction* actZoomOriginal = menu->addAction(ui.kZoomOriginal->icon(), ui.kZoomOriginal->toolTip());
+        QAction* actZoomOriginal = mainMenu->addAction(ui.kZoomOriginal->icon(), ui.kZoomOriginal->toolTip());
         connect(actZoomOriginal, SIGNAL(triggered(bool)), this, SLOT(onZoomOriginal()));
 
-        QAction* actZoomIn = menu->addAction(ui.kZoomIn->icon(), ui.kZoomIn->toolTip());
+        QAction* actZoomIn = mainMenu->addAction(ui.kZoomIn->icon(), ui.kZoomIn->toolTip());
         connect(actZoomIn, SIGNAL(triggered(bool)), this, SLOT(onZoomIn()));
 
-        QAction* actZoomOut = menu->addAction(ui.kZoomOut->icon(), ui.kZoomOut->toolTip());
+        QAction* actZoomOut = mainMenu->addAction(ui.kZoomOut->icon(), ui.kZoomOut->toolTip());
         connect(actZoomOut, SIGNAL(triggered(bool)), this, SLOT(onZoomOut()));
 
-        menu->addSeparator();
+        mainMenu->addSeparator();
 
-        QAction* actCopy = menu->addAction(ui.kCopy->icon(), ui.kCopy->toolTip());
+        QAction* actCopy = mainMenu->addAction(ui.kCopy->icon(), ui.kCopy->toolTip());
         connect(actCopy, SIGNAL(triggered(bool)), this, SLOT(onCopy()));
 
-        QAction* actPrint = menu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
+        QAction* actPrint = mainMenu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
         connect(actPrint, SIGNAL(triggered(bool)), this, SLOT(onPrint()));
 
-        QMenu* exp=menu->addMenu(i18n("Export"));
+        QMenu* exp=mainMenu->addMenu(i18n("Export"));
 
         QAction* actPDF = exp->addAction(KIcon("application-pdf"), i18n("Export PDF..."));
         connect(actPDF, SIGNAL(triggered(bool)), this, SLOT(onSavePDF()));
@@ -85,16 +85,29 @@ SKGGraphicsView::SKGGraphicsView(QWidget *parent)
         QAction* actImage = exp->addAction(KIcon("image-png"), i18n("Export image..."));
         connect(actImage, SIGNAL(triggered(bool)), this, SLOT(onSaveImage()));
 
-        menu->addSeparator();
+        mainMenu->addSeparator();
 
-        actShowToolBar = menu->addAction(i18n("Show tool bar"));
-        actShowToolBar->setCheckable(true);
-        actShowToolBar->setChecked(true);
-        connect(actShowToolBar, SIGNAL(triggered(bool)), this, SLOT(onSwitchToolBarVisibility()));
+        actShowToolBar = mainMenu->addAction(i18n("Show tool bar"));
+        if (actShowToolBar) {
+                actShowToolBar->setCheckable(true);
+                actShowToolBar->setChecked(true);
+                connect(actShowToolBar, SIGNAL(triggered(bool)), this, SLOT(onSwitchToolBarVisibility()));
+        }
+
+        actAntialiasing = mainMenu->addAction(i18n("Antialiasing"));
+        if (actAntialiasing) {
+                actAntialiasing->setCheckable(true);
+                actAntialiasing->setChecked(true);
+                onSwitchAntialiasing();
+                connect(actAntialiasing, SIGNAL(triggered(bool)), this, SLOT(onSwitchAntialiasing()));
+        }
 }
 
 SKGGraphicsView::~SKGGraphicsView()
 {
+        actAntialiasing=NULL;
+        actShowToolBar=NULL;
+        mainMenu=NULL;
 }
 
 void SKGGraphicsView::setScene ( QGraphicsScene * iScene )
@@ -115,6 +128,7 @@ QString SKGGraphicsView::getState() const
         doc.appendChild(root);
 
         root.setAttribute("isToolBarVisible", isToolBarVisible() ? "Y" : "N");
+        if (actAntialiasing) root.setAttribute("antialiasing", actAntialiasing->isChecked() ? "Y" : "N");
 
         return doc.toString();
 }
@@ -128,23 +142,26 @@ void SKGGraphicsView::setState(const QString& iState )
 
                 QString isToolBarVisible=root.attribute ("isToolBarVisible");
                 if (!isToolBarVisible.isEmpty()) setToolBarVisible(isToolBarVisible=="Y");
+
+                QString antialiasing=root.attribute ("antialiasing");
+                if (!antialiasing.isEmpty() && actAntialiasing) actAntialiasing->setChecked(antialiasing=="Y");
         }
 }
 
 KMenu* SKGGraphicsView::getContextualMenu() const
 {
-        return menu;
+        return mainMenu;
 }
 
 void SKGGraphicsView::showMenu(const QPoint& pos)
 {
-        menu->popup(this->mapToGlobal(pos));
+        if (mainMenu) mainMenu->popup(this->mapToGlobal(pos));
 }
 
 void SKGGraphicsView::setToolBarVisible(bool iVisibility)
 {
         ui.toolBar->setVisible(iVisibility);
-        actShowToolBar->setChecked(iVisibility);
+        if (actShowToolBar) actShowToolBar->setChecked(iVisibility);
 }
 
 bool SKGGraphicsView::isToolBarVisible() const
@@ -157,6 +174,11 @@ void SKGGraphicsView::onSwitchToolBarVisibility()
         setToolBarVisible(!isToolBarVisible());
 }
 
+void SKGGraphicsView::onSwitchAntialiasing()
+{
+        if (actAntialiasing) ui.kGraphicsView->setRenderHint(QPainter::Antialiasing, actAntialiasing->isChecked());
+}
+
 void SKGGraphicsView::onZoom()
 {
         _SKGTRACEIN(10, "SKGGraphicsView::onZoom");
