@@ -48,10 +48,13 @@
 #include <kfiledialog.h>
 #include <kmenu.h>
 #include <kcombobox.h>
+#include <kselectaction.h>
+#include <kstandarddirs.h>
 
 #include <QtGui/QProgressBar>
 #include <QtGui/QHeaderView>
 #include <QApplication>
+#include <QDir>
 
 bool SKGMainPanel::currentActionCanceled=false;
 SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument, const QStringList& iArguments)
@@ -180,37 +183,64 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                 tipsFile.close();
         }
 
-        // add a status bar
+        //Add a status bar
         statusBar()->show();
 
-        // add action to control hide / display of Context Chooser
+        //Add action to control hide / display of Context Chooser
         ui.kDockContext->toggleViewAction()->setText(i18n("Context Chooser"));
         ui.kDockContext->toggleViewAction()->setShortcut(Qt::SHIFT+Qt::Key_F9);
         actionCollection()->addAction("view_context", ui.kDockContext->toggleViewAction());
 
+        //Add style sheet menu
+        QDir dirTheme(KStandardDirs::locate("data", QString::fromLatin1("skrooge/theme/")));
+        dirTheme.setFilter(QDir::Files);
+        QStringList filters;
+        filters << "*.css";
+        dirTheme.setNameFilters(filters);
+        QStringList listThemes = dirTheme.entryList();
+        int nbt=listThemes.size();
+        if (nbt>1) {
+                defaultStyle=styleSheet();
+                KSelectAction* styleSheetMenu = new KSelectAction(KIcon("view-media-visualization"), i18n("Theme"), this);
+                actionCollection()->addAction( QLatin1String("view_stylesheet"), styleSheetMenu );
+
+                KSharedConfigPtr config=KSharedConfig::openConfig("skroogerc");
+                KConfigGroup pref=config->group("skrooge");
+                QString lastTheme=pref.readEntry("last_theme", "default");
+
+                for (int i=0; i<nbt ; ++i) {
+                        QString themeName=listThemes.at(i);
+                        themeName.remove(".css");
+
+                        KAction* action=styleSheetMenu->addAction(themeName);
+                        if (themeName==lastTheme) styleSheetMenu->setCurrentAction(action);
+                }
+                onChangeStyleSheet(lastTheme);
+                connect(styleSheetMenu, SIGNAL(triggered(QString)), this, SLOT(onChangeStyleSheet(QString)), Qt::QueuedConnection);
+        }
+
         //Add plugin in client in right order
         int nbplugin=pluginsList.count();
         for (int j=0; j<nbplugin; ++j) {
                 SKGInterfacePlugin *pluginInterface=pluginsList.at(j);
+                if (pluginInterface) {
+                        //Creation of the item
+                        QString title=pluginInterface->title();
+                        SKGTRACEL(1) << "Add plugin (" << pluginInterface->getOrder() << ") : " << title << endl;
+                        if (title.length()>0) {
+                                //Create icon to launch this plugin
+                                QListWidgetItem *contextItem = new QListWidgetItem(KIcon(pluginInterface->icon()), title);
+                                contextItem->setStatusTip(pluginInterface->statusTip());
+                                contextItem->setToolTip(pluginInterface->toolTip());
 
-                //Creation of the item
-                QString title=pluginInterface->title();
-                SKGTRACEL(1) << "Add plugin (" << pluginInterface->getOrder() << ") : " << title << endl;
-                if (title.length()>0) {
-                        //Create icon to launch this plugin
-                        QListWidgetItem *contextItem = new QListWidgetItem(KIcon(pluginInterface->icon()), title);
-                        contextItem->setStatusTip(pluginInterface->statusTip());
-                        contextItem->setToolTip(pluginInterface->toolTip());
+                                ui.kContextList->addItem(contextItem);
+                                ui.kContextList->setItemHidden (contextItem, !pluginInterface->isInContext());
 
-                        ui.kContextList->addItem(contextItem);
-                        ui.kContextList->setItemHidden (contextItem, !pluginInterface->isInContext());
+                                //TODO: Add menu item with shortcuts
 
-                        //TODO: Add menu item with shortcuts
-
-                        //Create dock if needed
-                        QDockWidget* dockWidget=pluginInterface->getDockWidget();
-                        if (dockWidget) {
-                                this->addDockWidget(Qt::LeftDockWidgetArea, dockWidget);
+                                //Create dock if needed
+                                QDockWidget* dockWidget=pluginInterface->getDockWidget();
+                                if (dockWidget)  this->addDockWidget(Qt::LeftDockWidgetArea, dockWidget);
                         }
                 }
         }
@@ -223,8 +253,12 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
         setupGUI(Default, "skrooge.rc");
 
         for (int j=0; j<nbplugin; ++j) {
-                guiFactory()->addClient(pluginsList.at(j));
-
+                SKGInterfacePlugin *pluginInterface=pluginsList.at(j);
+                if (pluginInterface) {
+                        QString title=pluginInterface->title();
+                        SKGTRACEL(1) << "Add plugin client (" << pluginInterface->getOrder() << ") : " << title << endl;
+                        guiFactory()->addClient(pluginInterface);
+                }
         }
 
         //Set status bar
@@ -320,8 +354,6 @@ KAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier)
 
 SKGInterfacePlugin * SKGMainPanel::getPluginByIndex(int iIndex)
 {
-        SKGTRACEIN(10, "SKGMainPanel::getPluginByIndex");
-        SKGTRACEL(10) << "Input parameter [iIndex]=[" << iIndex << ']' << endl;
         SKGInterfacePlugin * output=NULL;
         if (iIndex>=0 && iIndex<pluginsList.count()) {
                 output=pluginsList[iIndex];
@@ -332,8 +364,6 @@ SKGInterfacePlugin * SKGMainPanel::getPluginByIndex(int iIndex)
 
 SKGInterfacePlugin * SKGMainPanel::getPluginByName(const QString& iName)
 {
-        SKGTRACEIN(10, "SKGMainPanel::getPluginByName");
-        SKGTRACEL(10) << "Input parameter [iName]=[" << iName << ']' << endl;
         SKGInterfacePlugin * output=NULL;
         int nbplugin=pluginsList.count();
         for (int j=0; !output && j<nbplugin; ++j) {
@@ -417,14 +447,28 @@ bool SKGMainPanel::queryFileClose()
         bool output=true;
         if (currentBankDocument->getCurrentTransaction()) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-                KMessageBox::information(this,i18n("Application can be close until an operation is running."));
+                KMessageBox::information(this,i18n("Application can be closed until an operation is running."));
                 QApplication::restoreOverrideCursor();
                 output=false;
         } else if (currentBankDocument->isFileModified() && currentBankDocument->getDatabaseMode()!=SKGDocument::DirectAccess) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-                int code=KMessageBox::questionYesNo(this,i18n("Current modifications will not be saved.\nDo you want to continue ?"));
+                int code=KMessageBox::Cancel;
+                QString fileName=currentBankDocument->getCurrentFileName();
+                KAction* save=getGlobalAction(fileName.isEmpty() ? "file_save_as" : "file_save");
+                if (save) {
+                        code=KMessageBox::questionYesNoCancel(this, i18n("The document has been modified.\nDo you want to save it before closing ?"),
+                                                              QString(),
+                                                              KGuiItem (fileName.isEmpty() ?  i18n("Save as") : i18n("Save"),
+                                                                        KIcon(fileName.isEmpty() ?  "document-save-as" : "document-save")),
+                                                              KGuiItem (i18n("Do not save"))
+                                                             );
+                        if (code==KMessageBox::Yes) save->trigger();
+                        output=(code==KMessageBox::No || code==KMessageBox::Yes);
+                } else {
+                        code=KMessageBox::questionYesNo(this,i18n("Current modifications will not be saved.\nDo you want to continue ?"));
+                        output=(code==KMessageBox::Yes);
+                }
                 QApplication::restoreOverrideCursor();
-                output=(code==KMessageBox::Yes);
         }
 
         return output;
@@ -490,10 +534,11 @@ void SKGMainPanel::optionsPreferences()
         int nbplugin=pluginsList.count();
         for (int j=0; j<nbplugin; ++j) {
                 SKGInterfacePlugin *pluginInterface=getPluginByIndex(j);
-
-                QWidget* w=pluginInterface->getPreferenceWidget();
-                if (w) {
-                        dialog->addPage(w, pluginInterface->getPreferenceSkeleton(), pluginInterface->title(), pluginInterface->icon());
+                if (pluginInterface) {
+                        QWidget* w=pluginInterface->getPreferenceWidget();
+                        if (w) {
+                                dialog->addPage(w, pluginInterface->getPreferenceSkeleton(), pluginInterface->title(), pluginInterface->icon());
+                        }
                 }
         }
         connect(dialog, SIGNAL(settingsChanged(const QString&)), this, SLOT(onSettingsChanged()));
@@ -736,10 +781,10 @@ void SKGMainPanel::onTrayActivated(KSystemTrayIcon::ActivationReason reason)
 void SKGMainPanel::notify(int iTransaction)
 {
         SKGTRACEIN(1, "SKGMainPanel::notify");
+        SKGTRACEL(1) << "iTransaction=" << iTransaction << endl;
 
         //Notify
         if (iTransaction) {
-
                 SKGObjectBase transaction(currentBankDocument, "doctransaction", iTransaction);
                 if (transaction.getAttribute("t_mode")!="R") {
                         QStringList msg;
@@ -749,7 +794,7 @@ void SKGMainPanel::notify(int iTransaction)
                                 //Build message
                                 QString message;
                                 for (int i=0; i<nbMessages; ++i) {
-                                        if (i!=0) message+='\n';
+                                        if (i!=0) message+="<br>";
                                         message+=msg.at(i);
                                 }
 
@@ -801,6 +846,23 @@ void SKGMainPanel::onCancelCurrentAction()
         SKGMainPanel::currentActionCanceled=true;
 }
 
+void SKGMainPanel::onChangeStyleSheet(const QString& iNewStryle)
+{
+        QFile file(KStandardDirs::locate("data", QString::fromLatin1("skrooge/theme/")+iNewStryle+".css"));
+        if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                QTextStream in(&file);
+                setStyleSheet(defaultStyle+"\n"+in.readAll());
+
+                file.close();
+
+                KSharedConfigPtr config=KSharedConfig::openConfig("skroogerc");
+                KConfigGroup pref=config->group("skrooge");
+                pref.writeEntry("last_theme", iNewStryle);
+        } else {
+                SKGTRACE << "WARNING: " << file.fileName() << " does not exits for language [" << KGlobal::locale()->language() << "]" << endl;
+        }
+}
+
 int SKGMainPanel::progressBarCallBack(int iPos, void* iProgressBar)
 {
         QProgressBar* progressBar=NULL;
@@ -840,18 +902,20 @@ void SKGMainPanel::fillComboWithDistinctValue(
 {
         SKGTRACEIN(10, "SKGMainPanel::fillComboWithDistinctValue");
 
-        //Get list
-        QStringList list;
-        SKGServices::getDistinctValues(iDoc, iTable, iAttribut, iWhereClause, list);
-        if (list.count() && !list.at(0).isEmpty()) list.insert(0, "");
+        if (iComboBox) {
+                //Get list
+                QStringList list;
+                SKGServices::getDistinctValues(iDoc, iTable, iAttribut, iWhereClause, list);
+                if (list.count() && !list.at(0).isEmpty()) list.insert(0, "");
 
-        //Fill combo
-        iComboBox->clear();
-        iComboBox->addItems(list);
+                //Fill combo
+                iComboBox->clear();
+                iComboBox->addItems(list);
 
-        //Fill completion
-        KCompletion *comp = iComboBox->completionObject();
-        comp->clear ();
-        comp->insertItems(list);
+                //Fill completion
+                KCompletion *comp = iComboBox->completionObject();
+                comp->clear ();
+                comp->insertItems(list);
+        }
 }
 #include "skgmainpanel.moc"
