@@ -247,6 +247,7 @@ private slots:
         void setTabContentFromList(QListWidgetItem* item);
         void onTipOfDay();
         void onTrayActivated(QSystemTrayIcon::ActivationReason reason);
+        void onChangeStyleSheet(const QString& iNewStryle);
 private:
         Q_DISABLE_COPY(SKGMainPanel);
         void setupActions();
@@ -280,6 +281,7 @@ private:
         };
 
         doublePointer progressObjects;
+        QString defaultStyle;
 };
 
 #endif // SKGMAINPANEL_H
