@@ -70,6 +70,7 @@ SKGObjectModelBase::~SKGObjectModelBase()
 {
         SKGTRACEIN(1, "SKGObjectModelBase::~SKGObjectModelBase");
         clear();
+        document=NULL;
 }
 
 void SKGObjectModelBase::clear()
@@ -103,7 +104,7 @@ void SKGObjectModelBase::clear()
 
 int SKGObjectModelBase::getID(const SKGObjectBase* obj, int row) const
 {
-        return 100*(obj->getID())+row;
+        return (obj ? 100*(obj->getID())+row : 0);
 }
 
 QList<SKGObjectModelBase::SKGModelTemplate> SKGObjectModelBase::getSchemas() const
@@ -118,10 +119,11 @@ void SKGObjectModelBase::setSupportedAttributes ( const QStringList & iListAttri
         listSize.clear();
 
         if (iListAttribute.count()==0) {
-                listSupported=listSupportedDefault;
+                listSupported=SKGServices::splitCSVLine(listSchema.at(0).schema);
+//			listSupported=listSupportedDefault;
                 int nb=listSupported.count();
                 for (int i=0; i<nb; ++i) {
-                        listVisibility.push_back("Y");
+                        listVisibility.push_back(true);
                         listSize.push_back(-1);
                 }
         } else {
@@ -269,30 +271,32 @@ void SKGObjectModelBase::refresh()
                                         for (int i=0; i<listObjectToTreat.count(); ++i) { //WARNING: the list is modified during treatement
                                                 //Get parent
                                                 SKGObjectBase* parent=listObjectToTreat.at(i);
-                                                int parentid=listObjectToTreatId.at(i);
+                                                if (parent) {
+                                                        int parentid=listObjectToTreatId.at(i);
 
-                                                //Get children
-                                                SKGObjectBase::SKGListSKGObjectBase children;
-                                                QString wc=whereClauseChild;
-                                                wc.replace("#ID#", SKGServices::intToString(parent->getID()));
-                                                SKGObjectBase::SKGListSKGObjectBase* listObjectsChildren=new SKGObjectBase::SKGListSKGObjectBase();
-                                                if (listObjectsChildren) {
-                                                        SKGObjectBase::getObjects(document, table, wc, *listObjectsChildren);
+                                                        //Get children
+                                                        SKGObjectBase::SKGListSKGObjectBase children;
+                                                        QString wc=whereClauseChild;
+                                                        wc.replace("#ID#", SKGServices::intToString(parent->getID()));
+                                                        SKGObjectBase::SKGListSKGObjectBase* listObjectsChildren=new SKGObjectBase::SKGListSKGObjectBase();
+                                                        if (listObjectsChildren) {
+                                                                SKGObjectBase::getObjects(document, table, wc, *listObjectsChildren);
 
-                                                        //Addition relationship in hash table
-                                                        parentChildRelations.insert(parentid, listObjectsChildren);
-                                                        int nbc=listObjectsChildren->count();
-                                                        for (int k=0; k<nbc; ++k) {
-                                                                //Addition children in list to treat
-                                                                SKGObjectBase* c=new SKGObjectBase(listObjectsChildren->at(k));
-                                                                int childId=getID(c, k);
+                                                                //Addition relationship in hash table
+                                                                parentChildRelations.insert(parentid, listObjectsChildren);
+                                                                int nbc=listObjectsChildren->count();
+                                                                for (int k=0; k<nbc; ++k) {
+                                                                        //Addition children in list to treat
+                                                                        SKGObjectBase* c=new SKGObjectBase(listObjectsChildren->at(k));
+                                                                        int childId=getID(c, k);
 
-                                                                listObjectToTreat.push_back(c);
-                                                                listObjectToTreatId.push_back(childId);
+                                                                        listObjectToTreat.push_back(c);
+                                                                        listObjectToTreatId.push_back(childId);
 
-                                                                childParentRelations.insert(childId, parentid);
-                                                                objectsHashTableRows.insert(childId, k);
-                                                                objectsHashTable.insert(childId, c);
+                                                                        childParentRelations.insert(childId, parentid);
+                                                                        objectsHashTableRows.insert(childId, k);
+                                                                        objectsHashTable.insert(childId, c);
+                                                                }
                                                         }
                                                 }
                                         }
@@ -502,29 +506,33 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                 //Tooltip
                 if (doctransactionTable) {
                         SKGObjectBase* obj = getObjectPointer(index);
-                        QStringList msg;
-                        document->getMessages(obj->getID(), msg);
-                        int nbMessages=msg.count();
-                        if (nbMessages) {
-                                QString message;
-                                for (int i=0; i<nbMessages; ++i) {
-                                        if (i!=0) message+='\n';
-                                        message+=msg.at(i);
-                                }
+                        if (obj && document) {
+                                QStringList msg;
+                                document->getMessages(obj->getID(), msg);
+                                int nbMessages=msg.count();
+                                if (nbMessages) {
+                                        QString message;
+                                        for (int i=0; i<nbMessages; ++i) {
+                                                if (i!=0) message+='\n';
+                                                message+=msg.at(i);
+                                        }
 
-                                return message;
+                                        return message;
+                                }
                         }
                 } else if (getAttributeType(index.column())==SKGObjectModelBase::DATE) {
                         SKGObjectBase* obj = getObjectPointer(index);
-                        QString att=listAttibutes[index.column()];
-                        QString val=obj->getAttribute(att);
+                        if (obj) {
+                                QString att=listAttibutes[index.column()];
+                                QString val=obj->getAttribute(att);
 
-                        QDate dval=SKGServices::stringToTime(val).date();
-                        QString fancyDate=KGlobal::locale()->formatDate (dval, KLocale::FancyShortDate);
-                        QString shortDate=KGlobal::locale()->formatDate (dval, KLocale::ShortDate);
+                                QDate dval=SKGServices::stringToTime(val).date();
+                                QString fancyDate=KGlobal::locale()->formatDate (dval, KLocale::FancyShortDate);
+                                QString shortDate=KGlobal::locale()->formatDate (dval, KLocale::ShortDate);
 
 
-                        if (shortDate!=fancyDate) return shortDate;
+                                if (shortDate!=fancyDate) return shortDate;
+                        }
                 }
                 break;
         }
@@ -541,7 +549,7 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex &index) const
         Qt::ItemFlags flags=QAbstractItemModel::flags(index);
 
         if (nodeTable) {
-         //       flags|=Qt::ItemIsEditable;
+                //       flags|=Qt::ItemIsEditable;
 
                 if (index.isValid()) flags|=Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
                 else flags|=Qt::ItemIsDropEnabled;
@@ -596,7 +604,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData *data,
 {
         Q_UNUSED(row);
         if (action == Qt::IgnoreAction) return true;
-        if (!data->hasFormat("application/skrooge.node.ids")) return false;
+        if (!data || !data->hasFormat("application/skrooge.node.ids")) return false;
         if (column > 0) return false;
 
         QByteArray encodedData = data->data("application/skrooge.node.ids");
