@@ -49,6 +49,7 @@
 
 SKGTableView::SKGTableView(QWidget *parent)
                 : QTableView(parent),
+                header_menu(NULL),
                 autoResize(true), actAutoResize(NULL),
                 smoothScrolling(false), actSmoothScrolling(NULL),
                 document(NULL)
@@ -79,6 +80,7 @@ SKGTableView::SKGTableView(QWidget *parent)
 SKGTableView::~SKGTableView()
 {
         document=NULL;
+        header_menu=NULL;
 }
 
 bool SKGTableView::isAutoResized()
@@ -199,7 +201,7 @@ void SKGTableView::setState(const QString& iState )
                 }
 
                 //Set sort
-                if (!sortOrder.isEmpty() && !sortColumn.isEmpty()) {
+                if (model && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
                         int index=SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
                         if (index==-1) index=model->getIndexAttribute(sortColumn);
                         if (index==-1) index=0;
@@ -219,7 +221,7 @@ void SKGTableView::setState(const QString& iState )
 
 void SKGTableView::showHeaderMenu(const QPoint& pos)
 {
-        header_menu->popup(horizontalHeader()->mapToGlobal(pos));
+        if (header_menu) header_menu->popup(horizontalHeader()->mapToGlobal(pos));
 }
 
 void SKGTableView::setDefaultSaveParameters(const SKGDocument* iDocument, const QString& iParameterName)
@@ -239,108 +241,118 @@ void SKGTableView::setupHeaderMenu(bool iRefreshColumnSize)
         QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *>(model);
         if (proxyModel) model=(SKGObjectModelBase*) proxyModel->sourceModel();
 
-        header_menu->clear();
+        if (header_menu) {
+                header_menu->clear();
 
-        //Processing
-        QMenu* columns=header_menu->addMenu(i18n("Columns"));
+                //Processing
+                QMenu* columns=header_menu->addMenu(i18n("Columns"));
 
-        // Set right click menu
-        if (model) {
-                QList<SKGObjectModelBase::SKGModelTemplate> schemas=model->getSchemas();
-                int nbSchemas=schemas.count();
-                if (nbSchemas) {
-                        QMenu* viewAppearanceMenu=columns->addMenu(KIcon("view-file-columns"), i18n("View appearance"));
+                // Set right click menu
+                if (model) {
+                        QList<SKGObjectModelBase::SKGModelTemplate> schemas=model->getSchemas();
+                        int nbSchemas=schemas.count();
+                        if (nbSchemas) {
+                                QMenu* viewAppearanceMenu=columns->addMenu(KIcon("view-file-columns"), i18n("View appearance"));
 
-                        for (int i=0; i<nbSchemas; ++i) {
-                                SKGObjectModelBase::SKGModelTemplate schema=schemas.at(i);
-                                QAction* act = viewAppearanceMenu->addAction(schema.name);
-                                if (!schema.icon.isEmpty()) act->setIcon(KIcon(schema.icon));
-                                act->setData(schema.schema);
+                                for (int i=0; i<nbSchemas; ++i) {
+                                        SKGObjectModelBase::SKGModelTemplate schema=schemas.at(i);
+                                        QAction* act = viewAppearanceMenu->addAction(schema.name);
+                                        if (!schema.icon.isEmpty()) act->setIcon(KIcon(schema.icon));
+                                        act->setData(schema.schema);
 
-                                connect(act, SIGNAL(triggered(bool)), this, SLOT(changeSchema()));
-                        }
-                }
-        }
-
-        QAction* actResize = columns->addAction(KIcon("zoom-fit-width"), i18n("Resize to content"));
-        connect(actResize, SIGNAL(triggered(bool)), this, SLOT(resizeColumnsToContents()));
-
-        actAutoResize = columns->addAction(i18n("Auto resize"));
-        actAutoResize->setCheckable(true);
-        actAutoResize->setChecked(autoResize);
-        connect(actAutoResize, SIGNAL(triggered(bool)), this, SLOT(switchAutoResize()));
-
-        if (model && model->supportedDragActions()==Qt::IgnoreAction) {
-                actSmoothScrolling = header_menu->addAction(i18n("Smooth scrolling"));
-                actSmoothScrolling->setCheckable(true);
-                actSmoothScrolling->setChecked(smoothScrolling);
-                connect(actSmoothScrolling, SIGNAL(triggered(bool)), this, SLOT(switchSmoothScrolling()));
-        } else {
-                //Disable smooth scrolling
-                smoothScrolling=true;
-                switchSmoothScrolling();
-        }
-
-        QAction* actShowGrid = header_menu->addAction(KIcon("view-file-columns"),  i18n("Show grid"));
-        actShowGrid->setCheckable(true);
-        actShowGrid->setChecked(showGrid());
-        connect(actShowGrid, SIGNAL(triggered(bool)), this, SLOT(setShowGrid(bool)));
-
-        QAction* actAlternatingRowColors = header_menu->addAction(i18n("Alternate row colors"));
-        actAlternatingRowColors->setCheckable(true);
-        actAlternatingRowColors->setChecked(alternatingRowColors());
-        connect(actAlternatingRowColors, SIGNAL(triggered(bool)), this, SLOT(setAlternatingRowColors(bool)));
-
-        if (document) {
-                QAction* actDefault = header_menu->addAction(KIcon("document-save"), i18n("Save parameters"));
-                connect(actDefault, SIGNAL(triggered(bool)), this, SLOT(saveDefaultClicked()));
-        }
-
-        columns->addSeparator();
-
-        if (model) {
-                QHeaderView* hHeader=horizontalHeader();
-                int nbcol=hHeader->count();
-                for (int i=0; i<nbcol; ++i) {
-                        int idx=hHeader->logicalIndex(i);
-                        QString col = model->headerData(idx,Qt::Horizontal,Qt::UserRole).toString();
-                        QStringList values=col.split("|");
-
-                        if (iRefreshColumnSize) {
-                                if (values.count()>1) hHeader->setSectionHidden(idx, values.at(1)=="N");
-                                if (values.count()>2) {
-                                        int s=SKGServices::stringToInt(values.at(2));
-                                        if (s>0) hHeader->resizeSection(idx, s);
+                                        connect(act, SIGNAL(triggered(bool)), this, SLOT(changeSchema()));
                                 }
                         }
-                        QAction* act = columns->addAction(values.at(0));
-                        act->setCheckable(true);
-                        act->setChecked(!hHeader->isSectionHidden(idx));
-                        act->setIcon(model->headerData(idx,Qt::Horizontal,Qt::DecorationRole).value<QIcon>());
-                        act->setData(idx);
-
-                        connect(act, SIGNAL(triggered(bool)), this, SLOT(showHideColumn()));
                 }
+
+                QAction* actResize = columns->addAction(KIcon("zoom-fit-width"), i18n("Resize to content"));
+                connect(actResize, SIGNAL(triggered(bool)), this, SLOT(resizeColumnsToContents()));
+
+                actAutoResize = columns->addAction(i18n("Auto resize"));
+                actAutoResize->setCheckable(true);
+                actAutoResize->setChecked(autoResize);
+                connect(actAutoResize, SIGNAL(triggered(bool)), this, SLOT(switchAutoResize()));
+
+                if (model && model->supportedDragActions()==Qt::IgnoreAction) {
+                        actSmoothScrolling = header_menu->addAction(i18n("Smooth scrolling"));
+                        actSmoothScrolling->setCheckable(true);
+                        actSmoothScrolling->setChecked(smoothScrolling);
+                        connect(actSmoothScrolling, SIGNAL(triggered(bool)), this, SLOT(switchSmoothScrolling()));
+                } else {
+                        //Disable smooth scrolling
+                        smoothScrolling=true;
+                        switchSmoothScrolling();
+                }
+
+                QAction* actShowGrid = header_menu->addAction(KIcon("view-file-columns"),  i18n("Show grid"));
+                if (actShowGrid) {
+                        actShowGrid->setCheckable(true);
+                        actShowGrid->setChecked(showGrid());
+                        connect(actShowGrid, SIGNAL(triggered(bool)), this, SLOT(setShowGrid(bool)));
+                }
+
+                QAction* actAlternatingRowColors = header_menu->addAction(i18n("Alternate row colors"));
+                if (actAlternatingRowColors) {
+                        actAlternatingRowColors->setCheckable(true);
+                        actAlternatingRowColors->setChecked(alternatingRowColors());
+                        connect(actAlternatingRowColors, SIGNAL(triggered(bool)), this, SLOT(setAlternatingRowColors(bool)));
+                }
+
+                if (document) {
+                        QAction* actDefault = header_menu->addAction(KIcon("document-save"), i18n("Save parameters"));
+                        connect(actDefault, SIGNAL(triggered(bool)), this, SLOT(saveDefaultClicked()));
+                }
+
+                columns->addSeparator();
+
+                if (model) {
+                        QHeaderView* hHeader=horizontalHeader();
+                        int nbcol=hHeader->count();
+                        for (int i=0; i<nbcol; ++i) {
+                                int idx=hHeader->logicalIndex(i);
+                                QString col = model->headerData(idx,Qt::Horizontal,Qt::UserRole).toString();
+                                QStringList values=col.split("|");
+
+                                if (iRefreshColumnSize) {
+                                        if (values.count()>1) hHeader->setSectionHidden(idx, values.at(1)=="N");
+                                        if (values.count()>2) {
+                                                int s=SKGServices::stringToInt(values.at(2));
+                                                if (s>0) hHeader->resizeSection(idx, s);
+                                        }
+                                }
+                                QAction* act = columns->addAction(values.at(0));
+                                if (act) {
+                                        act->setCheckable(true);
+                                        act->setChecked(!hHeader->isSectionHidden(idx));
+                                        act->setIcon(model->headerData(idx,Qt::Horizontal,Qt::DecorationRole).value<QIcon>());
+                                        act->setData(idx);
+
+                                        connect(act, SIGNAL(triggered(bool)), this, SLOT(showHideColumn()));
+                                }
+                        }
+                }
+                header_menu->addSeparator();
+
+                QMenu* exp=header_menu->addMenu(i18n("Export"));
+
+                QAction* actPDF = exp->addAction(KIcon("application-pdf"), i18n("Export PDF..."));
+                connect(actPDF, SIGNAL(triggered(bool)), this, SLOT(onExportPDF()));
+
+                QAction* actCSV = exp->addAction(KIcon("text-csv"), i18n("Export CSV..."));
+                connect(actCSV, SIGNAL(triggered(bool)), this, SLOT(onExportCSV()));
+
+                QAction* actTXT = exp->addAction(KIcon("text-plain"), i18n("Export TXT..."));
+                connect(actTXT, SIGNAL(triggered(bool)), this, SLOT(onExportTXT()));
         }
-        header_menu->addSeparator();
-
-        QMenu* exp=header_menu->addMenu(i18n("Export"));
-
-        QAction* actPDF = exp->addAction(KIcon("application-pdf"), i18n("Export PDF..."));
-        connect(actPDF, SIGNAL(triggered(bool)), this, SLOT(onExportPDF()));
-
-        QAction* actCSV = exp->addAction(KIcon("text-csv"), i18n("Export CSV..."));
-        connect(actCSV, SIGNAL(triggered(bool)), this, SLOT(onExportCSV()));
-
-        QAction* actTXT = exp->addAction(KIcon("text-plain"), i18n("Export TXT..."));
-        connect(actTXT, SIGNAL(triggered(bool)), this, SLOT(onExportTXT()));
 }
 
 void SKGTableView::saveDefaultClicked()
 {
         SKGError err;
-        SKGBEGINTRANSACTION(*document, i18n("Save default parameters"), err);
-        err=document->setParameter(parameterName, getState());
+        if (document) {
+                SKGBEGINTRANSACTION(*document, i18n("Save default parameters"), err);
+                err=document->setParameter(parameterName, getState());
+        }
 }
 
 void SKGTableView::switchAutoResize()
