@@ -43,7 +43,7 @@ Qt::SortOrder SKGTableWithGraph::sortOrder=Qt::AscendingOrder;
 int SKGTableWithGraph::sortColumn=0;
 
 SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
-                : QWidget(parent), scene(NULL), nbLevel(0)
+                : QWidget(parent), scene(NULL), nbLevel(0), mainMenu(NULL)
 {
         ui.setupUi(this);
         ui.kLineUp->setIcon(KIcon("arrow-right"));
@@ -53,10 +53,10 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
         ui.kTable->setContextMenuPolicy(Qt::CustomContextMenu);
         connect(ui.kTable, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
-        menu = new KMenu(ui.kTable);
-        menu->addTitle(i18n("Table"));
+        mainMenu = new KMenu(ui.kTable);
+        mainMenu->addTitle(i18n("Table"));
 
-        QMenu* exp=menu->addMenu(i18n("Export"));
+        QMenu* exp=mainMenu->addMenu(i18n("Export"));
 
         QAction* actCSV = exp->addAction(KIcon("text-csv"), i18n("Export CSV..."));
         connect(actCSV, SIGNAL(triggered(bool)), this, SLOT(onExportCSV()));
@@ -95,11 +95,13 @@ SKGTableWithGraph::~SKGTableWithGraph()
                 delete scene;
                 scene=NULL;
         }
+
+        mainMenu=NULL;
 }
 
 KMenu* SKGTableWithGraph::getTableContextualMenu() const
 {
-        return menu;
+        return mainMenu;
 }
 
 KMenu* SKGTableWithGraph::getGraphContextualMenu() const
@@ -109,7 +111,7 @@ KMenu* SKGTableWithGraph::getGraphContextualMenu() const
 
 void SKGTableWithGraph::showMenu(const QPoint& pos)
 {
-        menu->popup(ui.kTable->mapToGlobal(pos));
+        if (mainMenu) mainMenu->popup(ui.kTable->mapToGlobal(pos));
 }
 
 QTableWidget* SKGTableWithGraph::table() const
@@ -428,6 +430,7 @@ void SKGTableWithGraph::refresh()
                                                 item->setToolTip(locale->formatMoney (vald/secondaryUnitValue, secondaryUnit, 2));
                                         }
 
+                                        item->setData(12, vald);
                                         item->setTextAlignment(Qt::AlignRight);
                                         if (vald<0) item->setForeground(QBrush(QColor(Qt::red)));
                                         ui.kTable->setItem(i-1, j, item);
@@ -532,7 +535,6 @@ void SKGTableWithGraph::redrawGraph()
                         nbColumns=nbColumns-2; //Sum and average
                         --sumColumnIndex;
                 }
-                KLocale* locale=KGlobal::locale();
                 QPen dotPen=QPen(Qt::DotLine);
 
                 int mode=ui.kDisplayMode->currentIndex();
@@ -546,13 +548,18 @@ void SKGTableWithGraph::redrawGraph()
                 //Compute y limits
                 double minLimit=0;
                 double maxLimit=0;
+                SKGTRACEL(30) << "mode=" << mode << endl;
+                SKGTRACEL(30) << "crow=" << crow << endl;
+                SKGTRACEL(30) << "ccolumn=" << ccolumn << endl;
+                SKGTRACEL(30) << "nbRows=" << nbRows << endl;
+                SKGTRACEL(30) << "nbColumns=" << nbColumns << endl;
+                SKGTRACEL(30) << "sumColumnIndex=" << sumColumnIndex << endl;
                 if (mode==0) {
                         //STACK
                         for (int x=0; x<nbRows; ++x) {
                                 QTableWidgetItem* tableItem=ui.kTable->item(x,sumColumnIndex);
                                 if (tableItem) {
-                                        QString valstring=tableItem->text();
-                                        double val=locale->readMoney(valstring);
+                                        double val=tableItem->data(12).toDouble();
                                         if (inPositive) {
                                                 maxLimit=qMax(maxLimit, fabs(val));
                                         } else {
@@ -567,8 +574,7 @@ void SKGTableWithGraph::redrawGraph()
                                 for (int y=0; y<nbColumns; ++y) {
                                         QTableWidgetItem* tableItem=ui.kTable->item(x,y);
                                         if (tableItem) {
-                                                QString valstring=tableItem->text();
-                                                double val=locale->readMoney(valstring);
+                                                double val=tableItem->data(12).toDouble();
                                                 if (inPositive) {
                                                         maxLimit=qMax(maxLimit, fabs(val));
                                                 } else {
@@ -579,6 +585,8 @@ void SKGTableWithGraph::redrawGraph()
                                 }
                         }
                 }
+                SKGTRACEL(30) << "minLimit=" << minLimit << endl;
+                SKGTRACEL(30) << "maxLimit=" << maxLimit << endl;
 
                 //Compute
                 double width=10;
@@ -592,6 +600,9 @@ void SKGTableWithGraph::redrawGraph()
                                 maxX=width*(nbColumns-1)*nbRows+width;
                         }
                 }
+                SKGTRACEL(30) << "width=" << width << endl;
+                SKGTRACEL(30) << "maxX=" << maxX << endl;
+
                 double margin=width;
                 if (mode!=2 && mode!=3) {//TODO for mode 2 or 3
                         scene->setSceneRect(-margin, -margin-maxLimit, maxX+margin, maxLimit-minLimit+2*margin);
@@ -616,8 +627,8 @@ void SKGTableWithGraph::redrawGraph()
                                 //Get cell value
                                 QTableWidgetItem* tableItem=ui.kTable->item(x,j);
                                 if (tableItem) {
+                                        double val=tableItem->data(12).toDouble();
                                         QString valstring=tableItem->text();
-                                        double val=locale->readMoney(valstring);
 
                                         int color_h=359*x/nbRows;
                                         int color_s=255-155*j/nbColumns;
@@ -660,7 +671,7 @@ void SKGTableWithGraph::redrawGraph()
                                                 for (int x2=0; x2<nbRows; ++x2) {
                                                         QTableWidgetItem* tableItem=ui.kTable->item(x2,j);
                                                         if (tableItem) {
-                                                                double absVal=abs(locale->readMoney(tableItem->text()));
+                                                                double absVal=abs(tableItem->data(12).toDouble());
                                                                 sumColumn+=absVal;
                                                                 if (x2<x) previousSum+=absVal;
                                                         }
@@ -785,14 +796,15 @@ void SKGTableWithGraph::redrawGraph()
 
 void SKGTableWithGraph::addArrow(const QPointF& iPeak, double iSize, double iArrowAngle, double iDegree)
 {
-        QPolygonF pol;
-        double radian=3.14*iArrowAngle/360;
-        pol << QPointF(0, 0) << QPointF(iSize*cos(radian), iSize*sin(radian)) << QPointF(iSize*cos(radian), -iSize*sin(radian)) << QPointF(0, 0);
-        QGraphicsPolygonItem * item=scene->addPolygon (pol, QPen(Qt::black), QBrush(Qt::black));
-        item->rotate(iDegree);
-        item->moveBy(iPeak.x(), iPeak.y());
-        item->setFlag(QGraphicsItem::ItemIsSelectable, false);
-
+        if (scene) {
+                QPolygonF pol;
+                double radian=3.14*iArrowAngle/360;
+                pol << QPointF(0, 0) << QPointF(iSize*cos(radian), iSize*sin(radian)) << QPointF(iSize*cos(radian), -iSize*sin(radian)) << QPointF(0, 0);
+                QGraphicsPolygonItem * item=scene->addPolygon (pol, QPen(Qt::black), QBrush(Qt::black));
+                item->rotate(iDegree);
+                item->moveBy(iPeak.x(), iPeak.y());
+                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+        }
 }
 
 void SKGTableWithGraph::onExportCSV()
