@@ -144,7 +144,7 @@ private:
         QString secondaryUnit;
         double secondaryUnitValue;
 
-        KMenu* menu;
+        KMenu* mainMenu;
 };
 
 #endif // SKGTABLEWITHGRAPH_H
