@@ -39,6 +39,8 @@ SKGTabWidget::SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
 SKGTabWidget::~SKGTabWidget()
 {
         SKGTRACEIN(5, "SKGTabWidget::~SKGTabWidget");
+        document=NULL;
+        parent=NULL;
 }
 
 bool SKGTabWidget::close()
