@@ -75,6 +75,7 @@ SKGTreeView::SKGTreeView(QWidget *parent)
 SKGTreeView::~SKGTreeView()
 {
         document=NULL;
+        header_menu=NULL;
 }
 
 bool SKGTreeView::isAutoResized()
@@ -193,7 +194,7 @@ void SKGTreeView::setState(const QString& iState )
                 }
 
                 //Set sort
-                if (!sortOrder.isEmpty() && !sortColumn.isEmpty()) {
+                if (model && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
                         int index=SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
                         if (index==-1) index=model->getIndexAttribute(sortColumn);
                         if (index==-1) index=0;
