@@ -307,10 +307,10 @@ SKGError SKGDocument::sendMessage(const QString& iMessage, bool iPopup)
                 if (err.isSucceeded()) err = msg.setAttribute("t_message", iMessage);
                 if (err.isSucceeded()) err = msg.setAttribute("t_popup", iPopup ? "Y" : "N");
                 if (err.isSucceeded()) err = msg.save();
+        } else {
+                //Addition message in global variable in case of no transaction opened
+                if (iPopup) unTransactionnalMessages.push_back(iMessage);
         }
-
-        //Addition message in global variable in case of
-        if (iPopup) unTransactionnalMessages.push_back(iMessage);
         return err;
 }
 
@@ -885,23 +885,27 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                 } else {
                                         //Open database
                                         if (getDatabaseMode()==CopiedInMemory) {
-                                                //Remove previous file
-                                                QFile(name).remove();
-
                                                 {//This scope is needed to avoid a warning at remove
-                                                        //Copy memory in file
-                                                        QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY");
-                                                        dbfile.setDatabaseName(name);
-                                                        if (!dbfile.open()) {
+                                                        //Remove previous file
+                                                        if (QFile(name).exists() && !QFile::remove(name)) {
                                                                 //Set error message
-                                                                QSqlError sqlErr=dbfile.lastError();
-                                                                err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
+                                                                err.setReturnCode(ERR_FAIL);
+                                                                err.setMessage(tr("Impossible to remove [%1]").arg(name));
                                                         } else {
-                                                                //Copy db from memory to file
-                                                                err = SKGServices::copySqliteDatabase(name, &dbfile, getDatabase(), false);
+                                                                //Copy memory in file
+                                                                QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY");
+                                                                dbfile.setDatabaseName(name);
+                                                                if (!dbfile.open()) {
+                                                                        //Set error message
+                                                                        QSqlError sqlErr=dbfile.lastError();
+                                                                        err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
+                                                                } else {
+                                                                        //Copy db from memory to file
+                                                                        err = SKGServices::copySqliteDatabase(name, &dbfile, getDatabase(), false);
 
-                                                                //Close db
-                                                                dbfile.close();
+                                                                        //Close db
+                                                                        dbfile.close();
+                                                                }
                                                         }
                                                 }
 
