@@ -37,7 +37,7 @@
 
 #include <sqlite3.h>
 
-int SKGServices::SKGSqlTraces = (getenv("SKGTRACESQL") ? atoi(getenv("SKGTRACESQL")) : 0);
+int SKGServices::SKGSqlTraces = SKGServices::stringToInt(SKGServices::getenv("SKGTRACESQL"));
 
 SKGError SKGServices::lastCallbackError;
 
@@ -45,6 +45,11 @@ SKGServices::SKGServices():QObject() {}
 
 SKGServices::~SKGServices() {}
 
+QString SKGServices::getenv(const QString& iAttribute)
+{
+        return QString::fromUtf8(qgetenv(iAttribute.toUtf8().constData()));
+}
+
 QString SKGServices::intToString(int iNumber)
 {
         QString output;
@@ -101,8 +106,18 @@ double SKGServices::stringToDouble(const QString& iNumber)
         double output=iNumber.toDouble(&ok);
         if (!ok) {
                 QString tmp=iNumber;
-                tmp.remove(',');
+                tmp.replace(',', '.');
                 output=tmp.toDouble(&ok);
+                if (!ok) {
+                        QString tmp=iNumber;
+                        tmp.replace('.', ',');
+                        output=tmp.toDouble(&ok);
+                        if (!ok) {
+                                QString tmp=iNumber;
+                                tmp.remove(',');
+                                output=tmp.toDouble(&ok);
+                        }
+                }
         }
         if (!ok) {
                 SKGTRACE << "WARNING: SKGServices::stringToDouble(" << iNumber << ") failed" << endl;
@@ -455,6 +470,9 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                                 // and output the resulting block. The ciphertext is the results of update()
                                 // and the result of final()
                                 fileOutput.write(f.toByteArray());
+
+                                //Close the file
+                                fileOutput.close();
                         }
                 }
         }
@@ -481,8 +499,8 @@ SKGError SKGServices::copySqliteDatabase(const QString& iFileDbFile, QSqlDatabas
         }
 
         // Attach the file iFileDbFile to the target
-        SKGTRACEL(20) << "Attaching the file..." << endl;
         if (err.isSucceeded()) {
+                SKGTRACEL(20) << "Attaching the file..." << endl;
                 err = SKGServices::executeSqliteOrder(iMemoryDb, "ATTACH DATABASE '" + iFileDbFile + "' as source");
                 if (err.isSucceeded()) {
                         // Copy the DATA from the source to the target
@@ -497,22 +515,23 @@ SKGError SKGServices::copySqliteDatabase(const QString& iFileDbFile, QSqlDatabas
                                 ++it; //To Forget the header
                                 for (; err.isSucceeded() &&it != listSqlOrder.end(); ++it) {
                                         QString val=*(it->begin());
-                                        if (iFromFileToMemory) {
-                                                err=SKGServices::executeSqliteOrder(iMemoryDb,                                                                                    "insert into main."+val+" select * from source."+val);
-                                        } else {
-                                                QString val=*(it->begin());
-                                                err=SKGServices::executeSqliteOrder(iMemoryDb,
-                                                                                    "insert into source."+val+" select * from main."+val);
-                                        }
+                                        if (iFromFileToMemory)  err=SKGServices::executeSqliteOrder(iMemoryDb, "insert into main."+val+" select * from source."+val);
+                                        else  err=SKGServices::executeSqliteOrder(iMemoryDb, "insert into source."+val+" select * from main."+val);
                                 }
 
                         }
-                        if (err.isSucceeded()) {
-                                err = SKGServices::executeSqliteOrder(iMemoryDb, "COMMIT");
-                        }
+                        if (err.isSucceeded())  err = SKGServices::executeSqliteOrder(iMemoryDb, "COMMIT");
 
                         //Detach
-                        SKGServices::executeSqliteOrder(iMemoryDb, "DETACH DATABASE source");
+                        SKGError err2=SKGServices::executeSqliteOrder(iMemoryDb, "DETACH DATABASE source");
+                        if (err.isSucceeded() && err2.isFailed()) err=err2;
+
+                        //Check if created file exists
+                        if (err.isSucceeded() && !iFromFileToMemory && !QFile(iFileDbFile).exists()) {
+                                //Set error message
+                                err.setReturnCode(ERR_FAIL);
+                                err.setMessage(tr("Creation file [%1] failed").arg(iFileDbFile));
+                        }
                 }
         }
         if (err.isFailed()) err.addError(SQLLITEERROR + ERR_FAIL, tr("copySqliteDatabase::copySqliteDatabase() failed"));
@@ -592,7 +611,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
                 //dump
                 int nb=oResult.size();
                 for (int i = 0; i < nb; ++i) {
-                        if (oStream==NULL) cout << oResult.at(i) << endl;
+                        if (oStream==NULL)  SKGTRACESUITE << oResult.at(i) << endl;
                         else  *oStream << oResult.at(i) << endl;
                 }
         }
