@@ -113,6 +113,13 @@ public:
                 DUMP_TEXT  /**< To dump in DUMP_TEXT mode */
         };
 
+        /**
+         * Get environment variable
+         * @param iAttribute name of the variable
+         * @return value of the variable
+         */
+        static QString getenv(const QString& iAttribute);
+
         /**
         * Convert a integer into a QString
         * @param iNumber the integer to convert
