@@ -32,6 +32,7 @@
 #include <kstandarddirs.h>
 
 #include <QDomDocument>
+#include <QFile>
 #include <QDir>
 
 SKGBankPluginWidget::SKGBankPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument)
@@ -64,12 +65,13 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
         ui.kAccountTableViewEdition->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_ACCOUNT");
 
         //Add registered global action in contextual menu
-        ui.kAccountTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
-        QAction* sep=new QAction(this);
-        sep->setSeparator(true);
-        ui.kAccountTableViewEdition->insertAction(0, sep);
-        ui.kAccountTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
-
+        if (iParent) {
+                ui.kAccountTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
+                QAction* sep=new QAction(this);
+                sep->setSeparator(true);
+                ui.kAccountTableViewEdition->insertAction(0, sep);
+                ui.kAccountTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
+        }
         connect(ui.kAccountTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                 this, SLOT(onSelectionChanged()));
 
@@ -80,28 +82,32 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
 
         //Logo for banks
         ui.kAccountCreatorIcon->addItem("");
-        QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")+KGlobal::locale()->language()+'/'));
-        dirLogo.setFilter(QDir::Files);
-        QStringList filters;
-        filters << "*.png";
-        dirLogo.setNameFilters(filters);
-        QStringList listLogo = dirLogo.entryList();
-        int nb=listLogo.size();
-        for (int i=0; i<nb ; ++i) {
-                QString bankName=listLogo.at(i);
-                bankName.remove(".png");
-                bankName.replace('_', ' ');
+        QFile file(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/list_bank.txt")));
+        if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
 
-                QRegExp rx("(.+) {2,}(.+)");
-                if (rx.indexIn(bankName)!=-1) {
-                        //Icon is something like <bank name>__<banknumber>.png
-                        listBankNumbers.append(rx.cap(2));
-                        bankName=rx.cap(1);
-                } else {
-                        listBankNumbers.append("");
+                QTextStream in(&file);
+                while (!in.atEnd()) {
+                        QString line=in.readLine().trimmed();
+                        if (!line.isEmpty()) {
+                                QString bankName=line;
+                                bankName.remove(".png");
+                                bankName.replace('_', ' ');
+
+                                QRegExp rx("(.+) {2,}(.+)");
+                                if (rx.indexIn(bankName)!=-1) {
+                                        //Icon is something like <bank name>__<banknumber>.png
+                                        listBankNumbers.append(rx.cap(2));
+                                        bankName=rx.cap(1);
+                                } else {
+                                        listBankNumbers.append("");
+                                }
+
+                                ui.kAccountCreatorIcon->addItem (QIcon(dirLogo.absoluteFilePath(line)), bankName);
+                        }
                 }
 
-                ui.kAccountCreatorIcon->addItem (QIcon(dirLogo.absoluteFilePath(listLogo.at(i))), bankName);
+                file.close();
         }
 
         //Refresh
@@ -113,6 +119,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
 SKGBankPluginWidget::~SKGBankPluginWidget()
 {
         SKGTRACEIN(10, "SKGBankPluginWidget::~SKGBankPluginWidget");
+        objectModel=NULL;
 }
 
 void SKGBankPluginWidget::onSelectionChanged()
@@ -120,51 +127,53 @@ void SKGBankPluginWidget::onSelectionChanged()
         SKGTRACEIN(10, "SKGBankPluginWidget::onSelectionChanged");
         //Mapping
         QItemSelectionModel *selModel=ui.kAccountTableViewEdition->selectionModel();
-        QModelIndexList indexes=selModel->selectedRows();
-        if (indexes.count()) {
-                QModelIndex idx=indexes[indexes.count()-1];
+        if (selModel) {
+                QModelIndexList indexes=selModel->selectedRows();
+                if (indexes.count() && objectModel) {
+                        QModelIndex idx=indexes[indexes.count()-1];
 
-                QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kAccountTableViewEdition->model();
-                QModelIndex idxs=proxyModel->mapToSource(idx);
+                        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kAccountTableViewEdition->model();
+                        QModelIndex idxs=proxyModel->mapToSource(idx);
 
-                //set the icon
-                SKGAccountObject account(objectModel->getObject(idxs));
-                SKGBankObject bank;
-                account.getBank(bank);
-                QString iconName=bank.getIcon();
-                if (iconName.length()) {
-                        iconName.remove(".png");
-                        iconName.replace('_', ' ');
+                        //set the icon
+                        SKGAccountObject account(objectModel->getObject(idxs));
+                        SKGBankObject bank;
+                        account.getBank(bank);
+                        QString iconName=bank.getIcon();
+                        if (iconName.length()) {
+                                iconName.remove(".png");
+                                iconName.replace('_', ' ');
 
-                        QRegExp rx("(.+) {2,}(.+)");
-                        if (rx.indexIn(iconName)!=-1) {
-                                iconName=rx.cap(1);
-                        }
-                        ui.kAccountCreatorIcon->setText(iconName);
-                } else ui.kAccountCreatorIcon->setText("");
+                                QRegExp rx("(.+) {2,}(.+)");
+                                if (rx.indexIn(iconName)!=-1) {
+                                        iconName=rx.cap(1);
+                                }
+                                ui.kAccountCreatorIcon->setText(iconName);
+                        } else ui.kAccountCreatorIcon->setText("");
 
-                ui.kAccountCreatorBank->setText(account.getAttribute("t_BANK"));
-                ui.kAccountCreatorAccount->setText(account.getAttribute("t_name"));
-                ui.kAccountCreatorBankNumber->setText(account.getAttribute("t_BANK_NUMBER"));
-                ui.kAccountCreatorAgencyNumber->setText(account.getAttribute("t_agency_number"));
-                ui.kAccountCreatorNumber->setText(account.getAttribute("t_number"));
-                ui.kAccountCreatorType->setText(account.getAttribute("t_TYPENLS"));
-                ui.kAccountCreatorAddress->setText(account.getAttribute("t_agency_address"));
-                ui.kAccountCreatorComment->setText(account.getAttribute("t_comment"));
-        } else {
-                ui.kAccountCreatorIcon->setText("");
-                ui.kAccountCreatorBank->setText("");
-                ui.kAccountCreatorAccount->setText("");
-                ui.kAccountCreatorBankNumber->setText("");
-                ui.kAccountCreatorAgencyNumber->setText("");
-                ui.kAccountCreatorNumber->setText("");
-                //Not done because of it's a combo ui.kAccountCreatorType->setText("");
-                ui.kAccountCreatorAddress->setText("");
-                ui.kAccountCreatorComment->setText("");
+                        ui.kAccountCreatorBank->setText(account.getAttribute("t_BANK"));
+                        ui.kAccountCreatorAccount->setText(account.getAttribute("t_name"));
+                        ui.kAccountCreatorBankNumber->setText(account.getAttribute("t_BANK_NUMBER"));
+                        ui.kAccountCreatorAgencyNumber->setText(account.getAttribute("t_agency_number"));
+                        ui.kAccountCreatorNumber->setText(account.getAttribute("t_number"));
+                        ui.kAccountCreatorType->setText(account.getAttribute("t_TYPENLS"));
+                        ui.kAccountCreatorAddress->setText(account.getAttribute("t_agency_address"));
+                        ui.kAccountCreatorComment->setText(account.getAttribute("t_comment"));
+                } else {
+                        ui.kAccountCreatorIcon->setText("");
+                        ui.kAccountCreatorBank->setText("");
+                        ui.kAccountCreatorAccount->setText("");
+                        ui.kAccountCreatorBankNumber->setText("");
+                        ui.kAccountCreatorAgencyNumber->setText("");
+                        ui.kAccountCreatorNumber->setText("");
+                        //Not done because of it's a combo ui.kAccountCreatorType->setText("");
+                        ui.kAccountCreatorAddress->setText("");
+                        ui.kAccountCreatorComment->setText("");
+                }
+
+                onAccountCreatorModified();
+                emit selectionChanged();
         }
-
-        onAccountCreatorModified();
-        emit selectionChanged();
 }
 
 void SKGBankPluginWidget::onAccountCreatorModified()
@@ -384,9 +393,13 @@ void SKGBankPluginWidget::onFilterChanged()
 
         //Update model
         QSortFilterProxyModel* modelproxy = (QSortFilterProxyModel*) ui.kAccountTableViewEdition->model();
-        SKGObjectModel* modelview=(SKGObjectModel*) modelproxy->sourceModel ();
-        modelview->setFilter(filter);
-        modelview->refresh();
+        if (modelproxy) {
+                SKGObjectModel* modelview=(SKGObjectModel*) modelproxy->sourceModel ();
+                if (modelview) {
+                        modelview->setFilter(filter);
+                        modelview->refresh();
+                }
+        }
 
         //Correction bug 2299394 vvv
         if (ui.kAccountTableViewEdition->isAutoResized()) ui.kAccountTableViewEdition->resizeColumnsToContents();
