@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is Skrooge plugin for undoredo management.
+ * This file is Skrooge plugin for bookmarks management.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -54,22 +54,22 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
         connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
-        menu = new KMenu(ui.kBookmarksList);
-        actDelete = menu->addAction(ui.kRemoveBookmark->icon(), i18n("Delete"));
+        mainMenu = new KMenu(ui.kBookmarksList);
+        actDelete = mainMenu->addAction(ui.kRemoveBookmark->icon(), i18n("Delete"));
         connect(actDelete, SIGNAL(triggered(bool)), this, SLOT(onRemoveBookmark()));
 
-        menu->addSeparator();
+        mainMenu->addSeparator();
 
-        actAddBookmarkGroup = menu->addAction(ui.kAddBookmarkGroup->icon(), ui.kAddBookmarkGroup->toolTip());
+        actAddBookmarkGroup = mainMenu->addAction(ui.kAddBookmarkGroup->icon(), ui.kAddBookmarkGroup->toolTip());
         connect(actAddBookmarkGroup, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarkGroup()));
 
-        actAddBookmark = menu->addAction(ui.kAddBookmark->icon(), ui.kAddBookmark->toolTip());
+        actAddBookmark = mainMenu->addAction(ui.kAddBookmark->icon(), ui.kAddBookmark->toolTip());
         connect(actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
 
-        actSetAutostart = menu->addAction(KIcon("user-online"), i18n("Autostart"));
+        actSetAutostart = mainMenu->addAction(KIcon("user-online"), i18n("Autostart"));
         connect(actSetAutostart, SIGNAL(triggered(bool)), this, SLOT(onSetAutostart()));
 
-        actUnsetAutostart = menu->addAction(KIcon("user-offline"), i18n("Remove Autostart"));
+        actUnsetAutostart = mainMenu->addAction(KIcon("user-offline"), i18n("Remove Autostart"));
         connect(actUnsetAutostart, SIGNAL(triggered(bool)), this, SLOT(onUnsetAutostart()));
 
 
@@ -87,11 +87,17 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
 SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget");
+        mainMenu=NULL;
+        actDelete=NULL;
+        actAddBookmark=NULL;
+        actAddBookmarkGroup=NULL;
+        actSetAutostart=NULL;
+        actUnsetAutostart=NULL;
 }
 
 void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
 {
-        menu->popup(ui.kBookmarksList->mapToGlobal(pos));
+        if (mainMenu) mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
 }
 
 int SKGBookmarkPluginDockWidget::getNbSelectedBookmarks()
@@ -371,12 +377,12 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
         //Enable bookmark buttons
         bool testAdd=getDocument()->getDatabase()!=NULL && nbSelectedObjects<=1 && isFolder;
         ui.kAddBookmarkGroup->setEnabled(testAdd);
-        actAddBookmarkGroup->setEnabled(ui.kAddBookmarkGroup->isEnabled());
+        if (actAddBookmarkGroup) actAddBookmarkGroup->setEnabled(ui.kAddBookmarkGroup->isEnabled());
         ui.kAddBookmark->setEnabled(testAdd && getMainPanel()->currentTabIndex()>=0);
-        actAddBookmark->setEnabled(ui.kAddBookmark->isEnabled());
+        if (actAddBookmark) actAddBookmark->setEnabled(ui.kAddBookmark->isEnabled());
         ui.kRenameBookmark->setEnabled(nbSelectedObjects==1 && !ui.kRenameBookmarkEdit->text().isEmpty());
         ui.kRemoveBookmark->setEnabled(nbSelectedObjects>0);
-        actDelete->setEnabled(ui.kRemoveBookmark->isEnabled());
+        if (actDelete) actDelete->setEnabled(ui.kRemoveBookmark->isEnabled());
         ui.kRenameBookmarkEdit->setEnabled(getDocument()->getDatabase()!=NULL && nbSelectedObjects<=1);
 
 }
@@ -406,13 +412,8 @@ void SKGBookmarkPluginDockWidget::refresh()
                 SKGNodeObject node=bookmarks.at(0);
                 ui.kRenameBookmarkEdit->setText(node.getName());
 
-                if (node.getAttribute("t_autostart") == "Y") {
-                        actSetAutostart->setEnabled(false);
-                        actUnsetAutostart->setEnabled(true);
-                } else {
-                        actSetAutostart->setEnabled(true);
-                        actUnsetAutostart->setEnabled(false);
-                }
+                if (actSetAutostart) actSetAutostart->setEnabled(node.getAttribute("t_autostart")!="Y");
+                if (actUnsetAutostart) actUnsetAutostart->setEnabled(node.getAttribute("t_autostart")=="Y");
         }
 
         onBookmarkEditorChanged();
@@ -420,19 +421,22 @@ void SKGBookmarkPluginDockWidget::refresh()
 
 void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent *event)
 {
-        QSize newSize=event->size ();
-        if (newSize.height()<=minSize.height() || newSize.width()<=minSize.width()) {
-                ui.kActionsFrame->hide();
-        } else {
-                ui.kActionsFrame->show();
+        if (event) {
+                QSize newSize=event->size ();
+                if (newSize.height()<=minSize.height() || newSize.width()<=minSize.width()) {
+                        ui.kActionsFrame->hide();
+                } else {
+                        ui.kActionsFrame->show();
+                }
+
+                //Compute icon size
+                int s=qMax(qMin(newSize.width()/5,64),16);
+                ui.kBookmarksList->setIconSize(QSize(s, s));
+
+                //TODO: must be fixed
+                getMainPanel()->contextList()->setIconSize(QSize(s, s));
         }
 
-        //Compute icon size
-        int s=qMax(qMin(newSize.width()/5,64),16);
-        ui.kBookmarksList->setIconSize(QSize(s, s));
-
-        getMainPanel()->contextList()->setIconSize(QSize(s, s));
-
         QWidget::resizeEvent(event);
 }
 
