@@ -53,6 +53,9 @@ SKGFilePlugin::~SKGFilePlugin()
 
         parent=NULL;
         currentBankDocument=NULL;
+        recentFiles=NULL;
+        saveAction=NULL;
+        saveAsAction=NULL;
 }
 
 void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -67,30 +70,39 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
         setXMLFile("skrooge_file.rc");
 
         //Menu
-        KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
-        KStandardAction::open(this, SLOT(actionOpen()), actionCollection());
+        KAction* opennew=KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
+        if (parent) parent->registedGlobalAction("file_new", opennew);
+
+        KAction* open=KStandardAction::open(this, SLOT(actionOpen()), actionCollection());
+        if (parent) parent->registedGlobalAction("file_open", open);
+
         saveAction=KStandardAction::save(this, SLOT(actionSave()), actionCollection());
+        if (parent) parent->registedGlobalAction("file_save", saveAction);
+
         saveAsAction=KStandardAction::saveAs(this, SLOT(actionSaveAs()), actionCollection());
+        if (parent) parent->registedGlobalAction("file_save_as", saveAsAction);
 
         KAction* passwordAction = new KAction(KIcon("document-encrypt"), i18n("&Change password..."), this);
         connect(passwordAction, SIGNAL(triggered(bool)), this, SLOT(actionChangePassword()));
         actionCollection()->addAction( QLatin1String("file_change_password"), passwordAction );
         passwordAction->setShortcut(Qt::CTRL+Qt::Key_K);
 
-        iParent->registedGlobalAction("file_change_password", passwordAction);
+        if (parent) parent->registedGlobalAction("file_change_password", passwordAction);
 
         //Recent file
         recentFiles=KStandardAction::openRecent(this,SLOT(actionOpen(const KUrl)), actionCollection());
-        recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+        if (recentFiles) recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
 
         //Get last argument
         connect(this, SIGNAL(loadFile(const KUrl)), this, SLOT(actionOpen(const KUrl)), Qt::QueuedConnection);
 
         int nbArg=iArgument.count();
         if (nbArg && QFile(iArgument.at(nbArg-1)).exists()) {
-                KSplashScreen* splashScreen=parent->splashScreen();
                 QString filename=iArgument.at(nbArg-1);
-                if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", filename), Qt::AlignLeft, QColor(221, 130, 8));
+                if (parent) {
+                        KSplashScreen* splashScreen=parent->splashScreen();
+                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", filename), Qt::AlignLeft, QColor(221, 130, 8));
+                }
                 emit loadFile(filename);
         } else {
                 //Read Setting
@@ -101,8 +113,10 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
                         SKGTRACEIN(10, "SKGFilePlugin::openlastfile");
                         QString lastOpenedFile=pref.readPathEntry("lastfilepath",""); // krazy:exclude=doublequote_chars
                         if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
-                                KSplashScreen* splashScreen=parent->splashScreen();
-                                if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));
+                                if (parent) {
+                                        KSplashScreen* splashScreen=parent->splashScreen();
+                                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));
+                                }
                                 emit loadFile(lastOpenedFile);
                         }
                 } else {
@@ -130,8 +144,10 @@ void SKGFilePlugin::refresh()
         SKGTRACEIN(10, "SKGFilePlugin::refresh");
 
         //Refresh action status
-        saveAction->setEnabled(currentBankDocument->isFileModified() && currentBankDocument->getCurrentFileName().length()>0);
-        saveAsAction->setEnabled(currentBankDocument->getDatabase()!=NULL);
+        if (currentBankDocument) {
+                if (saveAction) saveAction->setEnabled(currentBankDocument->isFileModified() && currentBankDocument->getCurrentFileName().length()>0);
+                if (saveAsAction) saveAsAction->setEnabled(currentBankDocument->getDatabase()!=NULL);
+        }
 }
 
 QString SKGFilePlugin::title() const
@@ -177,7 +193,7 @@ void SKGFilePlugin::actionNew()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionNew",err);
-        if (parent->queryFileClose()) {
+        if (parent && currentBankDocument && parent->queryFileClose()) {
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
                 parent->closeAllTabs();
@@ -227,7 +243,7 @@ void SKGFilePlugin::actionNew()
                 else err.addError(ERR_FAIL, i18n("Document creation failed"));
 
                 //Display error
-                parent->displayErrorMessage(err);
+                if (parent) parent->displayErrorMessage(err);
         }
 }
 
@@ -235,59 +251,63 @@ void SKGFilePlugin::actionSave()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionSave",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        err=currentBankDocument->save();
-        QApplication::restoreOverrideCursor();
+        if (currentBankDocument && parent) {
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                err=currentBankDocument->save();
+                QApplication::restoreOverrideCursor();
 
-        //Refresh
-        parent->refresh();
+                //Refresh
+                parent->refresh();
 
-        //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
-        else err.addError(ERR_FAIL, i18n("Cannot save file"));
+                //status bar
+                if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
+                else err.addError(ERR_FAIL, i18n("Cannot save file"));
 
-        //Display error
-        parent->displayErrorMessage(err);
+                //Display error
+                parent->displayErrorMessage(err);
+        }
 }
 
 void SKGFilePlugin::actionSaveAs()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionSaveAs",err);
-        QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///SKG"), i18n("*.skg|Skrooge document") , parent);
-        if (fileName.isEmpty()) return;
+        if (currentBankDocument && parent) {
+                QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///SKG"), i18n("*.skg|Skrooge document") , parent);
+                if (fileName.isEmpty()) return;
 
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        err=currentBankDocument->saveAs(fileName, true);
-        QApplication::restoreOverrideCursor();
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                err=currentBankDocument->saveAs(fileName, true);
+                QApplication::restoreOverrideCursor();
 
-        //Refresh
-        parent->refresh();
+                //Refresh
+                parent->refresh();
 
-        //status bar
-        if (err.isSucceeded()) {
-                err=SKGError(0, i18n("File [%1] saved.", fileName));
-                //Add in recentFiles
-                if (recentFiles) {
-                        recentFiles->addUrl(fileName);
-                        recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
-                }
-                //Set as last open file in kcfg
-                KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_filerc");
-                KConfigGroup pref=config->group("File");
-                pref.writePathEntry("lastfilepath",fileName);
+                //status bar
+                if (err.isSucceeded()) {
+                        err=SKGError(0, i18n("File [%1] saved.", fileName));
+                        //Add in recentFiles
+                        if (recentFiles) {
+                                recentFiles->addUrl(fileName);
+                                recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+                        }
+                        //Set as last open file in kcfg
+                        KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_filerc");
+                        KConfigGroup pref=config->group("File");
+                        pref.writePathEntry("lastfilepath",fileName);
 
-        } else err.addError(ERR_FAIL, i18n("Save of [%1] failed", fileName));
+                } else err.addError(ERR_FAIL, i18n("Save of [%1] failed", fileName));
 
-        //Display error
-        parent->displayErrorMessage(err);
+                //Display error
+                parent->displayErrorMessage(err);
+        }
 }
 
 void SKGFilePlugin::actionOpen(const KUrl & iUrl)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionOpen",err);
-        if (parent->queryFileClose()) {
+        if (parent && currentBankDocument && parent->queryFileClose()) {
 
                 QString fileName=iUrl.path();
                 if (!fileName.length()) fileName=KFileDialog::getOpenFileName(KUrl("kfiledialog:///SKG"), "*.skg|"+i18n("Skrooge document") , parent);
@@ -346,7 +366,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                         } else  err.addError(ERR_FAIL, i18n("Open of [%1] failed", fileName));
 
                         //Display error
-                        parent->displayErrorMessage(err);
+                        if (parent) parent->displayErrorMessage(err);
                 }
         }
 }
@@ -355,32 +375,33 @@ void SKGFilePlugin::actionChangePassword()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionChangePassword",err);
+        if (currentBankDocument) {
+                KDialog* d=new KDialog(parent);
+                QFrame* f=new QFrame(d);
+                uipwd.setupUi(f);
+                d->setMainWidget( f );
+                uipwd.kPwd1->setFocus();
+                uipwd.kTitle->setPixmap(KIcon("document-encrypt").pixmap(48, 48));
+                if (d->exec()==QDialog::Accepted) {
+                        QString pwd1=uipwd.kPwd1->text();
+                        QString pwd2=uipwd.kPwd2->text();
+                        if (pwd1==pwd2) {
+                                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Change password"), err);
+                                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                                err=currentBankDocument->changePassword(pwd1);
+                                QApplication::restoreOverrideCursor();
 
-        KDialog* d=new KDialog(parent);
-        QFrame* f=new QFrame(d);
-        uipwd.setupUi(f);
-        d->setMainWidget( f );
-        uipwd.kPwd1->setFocus();
-        uipwd.kTitle->setPixmap(KIcon("document-encrypt").pixmap(48, 48));
-        if (d->exec()==QDialog::Accepted) {
-                QString pwd1=uipwd.kPwd1->text();
-                QString pwd2=uipwd.kPwd2->text();
-                if (pwd1==pwd2) {
-                        SKGBEGINTRANSACTION(*currentBankDocument, i18n("Change password"), err);
-                        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-                        err=currentBankDocument->changePassword(pwd1);
-                        QApplication::restoreOverrideCursor();
-
-                        //status
-                        if (err.isSucceeded())  err=SKGError(0, i18n("password changed."));
-                        else err.addError(ERR_FAIL, i18n("Change password failed"));
+                                //status
+                                if (err.isSucceeded())  err=SKGError(0, i18n("password changed."));
+                                else err.addError(ERR_FAIL, i18n("Change password failed"));
+                        } else {
+                                err=SKGError(ERR_FAIL, i18n("First and second passwords are different."));
+                        }
                 } else {
-                        err=SKGError(ERR_FAIL, i18n("First and second passwords are different."));
+                        err=SKGError(0, i18n("Change password canceled."));
                 }
-        } else {
-                err=SKGError(0, i18n("Change password canceled."));
+                //Display error
+                if (parent) parent->displayErrorMessage(err);
         }
-        //Display error
-        parent->displayErrorMessage(err);
 }
 #include "skgfileplugin.moc"
