@@ -46,6 +46,16 @@ SKGImportExportPlugin::~SKGImportExportPlugin()
         SKGTRACEIN(10, "SKGImportExportPlugin::~SKGImportExportPlugin");
         parent=NULL;
         currentBankDocument=NULL;
+
+        importQifAction=NULL;
+        importOfxAction=NULL;
+        importCsvAction=NULL;
+        importCsvUnitAction=NULL;
+        exportCsvAction=NULL;
+        exportQifAction=NULL;
+        processingFoundTransfert=NULL;
+        processingBankPerfect=NULL;
+        processingBank=NULL;
 }
 
 void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -73,7 +83,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("import_ofx"), importOfxAction );
         imports->addAction(importOfxAction);
 
-        iParent->registedGlobalAction("import_ofx", importOfxAction);
+        if (parent) parent->registedGlobalAction("import_ofx", importOfxAction);
 
         //Import QIF
         QStringList overlaycsv;
@@ -84,7 +94,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("import_qif"), importQifAction );
         imports->addAction(importQifAction);
 
-        iParent->registedGlobalAction("import_qif", importQifAction);
+        if (parent) parent->registedGlobalAction("import_qif", importQifAction);
 
         //Import CSV
         importCsvAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18n("Import &CSV..."), this);
@@ -92,7 +102,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("import_csv"), importCsvAction );
         imports->addAction(importCsvAction);
 
-        iParent->registedGlobalAction("import_csv", importCsvAction);
+        if (parent) parent->registedGlobalAction("import_csv", importCsvAction);
 
         //Import CSV Unit
         importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18n("Import CSV &Unit..."), this);
@@ -100,7 +110,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("import_csv_unit"), importCsvUnitAction );
         imports->addAction(importCsvUnitAction);
 
-        iParent->registedGlobalAction("import_csv_unit", importCsvUnitAction);
+        if (parent) parent->registedGlobalAction("import_csv_unit", importCsvUnitAction);
 
         //Exports
         KActionMenu* exports=new  KActionMenu(KIcon("document-export"),i18n("Export"), this);
@@ -112,7 +122,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("export_qif"), exportQifAction );
         exports->addAction(exportQifAction);
 
-        iParent->registedGlobalAction("export_qif", exportQifAction);
+        if (parent) parent->registedGlobalAction("export_qif", exportQifAction);
 
         //Export CSV
         exportCsvAction = new KAction(KIcon("document-export", NULL, overlaycsv), i18n("Export &CSV..."), this);
@@ -120,7 +130,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("export_csv"), exportCsvAction );
         exports->addAction(exportCsvAction);
 
-        iParent->registedGlobalAction("export_csv", exportCsvAction);
+        if (parent) parent->registedGlobalAction("export_csv", exportCsvAction);
 
         //Processing
         KActionMenu* processing=new  KActionMenu(KIcon("tools-wizard"),i18n("Processing"), this);
@@ -135,7 +145,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("process_foundtransfer"), processingFoundTransfert );
         processing->addAction(processingFoundTransfert);
 
-        iParent->registedGlobalAction("process_foundtransfer", processingFoundTransfert);
+        if (parent) parent->registedGlobalAction("process_foundtransfer", processingFoundTransfert);
 
         //Processing bankperfect
         processingBankPerfect = new KAction(KIcon("tools-wizard"), i18n("Clean BankPerfect's imports"), this);
@@ -143,7 +153,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("process_bankperfect"), processingBankPerfect );
         processing->addAction(processingBankPerfect);
 
-        iParent->registedGlobalAction("process_bankperfect", processingBankPerfect);
+        if (parent) parent->registedGlobalAction("process_bankperfect", processingBankPerfect);
 
         //Processing banks
         processingBank = new KAction(KIcon("tools-wizard"), i18n("Clean bank's imports"), this);
@@ -151,7 +161,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         actionCollection()->addAction( QLatin1String("process_banks"), processingBank );
         processing->addAction(processingBank);
 
-        iParent->registedGlobalAction("process_banks", processingBank);
+        if (parent) parent->registedGlobalAction("process_banks", processingBank);
 
 }
 
@@ -193,15 +203,17 @@ void SKGImportExportPlugin::refresh()
 {
         SKGTRACEIN(10, "SKGImportExportPlugin::refresh");
 
-        bool test=(currentBankDocument->getDatabase()!=NULL);
-        importQifAction->setEnabled(test);
-        importOfxAction->setEnabled(test);
-        importCsvAction->setEnabled(test);
-        exportQifAction->setEnabled(test);
-        exportCsvAction->setEnabled(test);
-        processingFoundTransfert->setEnabled(test);
-        processingBankPerfect->setEnabled(test);
-        processingBank->setEnabled(test);
+        if (currentBankDocument) {
+                bool test=(currentBankDocument->getDatabase()!=NULL);
+                if (importQifAction) importQifAction->setEnabled(test);
+                if (importOfxAction) importOfxAction->setEnabled(test);
+                if (importCsvAction) importCsvAction->setEnabled(test);
+                if (exportQifAction) exportQifAction->setEnabled(test);
+                if (exportCsvAction) exportCsvAction->setEnabled(test);
+                if (processingFoundTransfert) processingFoundTransfert->setEnabled(test);
+                if (processingBankPerfect) processingBankPerfect->setEnabled(test);
+                if (processingBank) processingBank->setEnabled(test);
+        }
 }
 
 void SKGImportExportPlugin::close()
@@ -241,56 +253,58 @@ void SKGImportExportPlugin::import(SKGImportExportManager::ImportExportMode iMod
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::import",err);
-        QString lastCodecUsed=currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
-        if (lastCodecUsed.length()==0) lastCodecUsed=QTextCodec::codecForLocale()->name();
+        if (currentBankDocument) {
+                QString lastCodecUsed=currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
+                if (lastCodecUsed.length()==0) lastCodecUsed=QTextCodec::codecForLocale()->name();
 
-        KEncodingFileDialog::Result result=KEncodingFileDialog::getOpenFileNamesAndEncoding(lastCodecUsed,
-                                           "kfiledialog:///IMPEXP",
-                                           iMode==SKGImportExportManager::CSV || iMode==SKGImportExportManager::CSVUNIT ?
-                                           "*.csv|"+i18n("CSV Files") :
-                                           iMode==SKGImportExportManager::OFX ? "*.ofx|"+i18n("OFX Files") : "*.qif|"+i18n("QIF Files") ,
-                                           parent);
-        QSet<QString> fileNames=result.fileNames.toSet();
-        QString codec=result.encoding;
+                KEncodingFileDialog::Result result=KEncodingFileDialog::getOpenFileNamesAndEncoding(lastCodecUsed,
+                                                   "kfiledialog:///IMPEXP",
+                                                   iMode==SKGImportExportManager::CSV || iMode==SKGImportExportManager::CSVUNIT ?
+                                                   "*.csv|"+i18n("CSV Files") :
+                                                   iMode==SKGImportExportManager::OFX ? "*.ofx|"+i18n("OFX Files") : "*.qif|"+i18n("QIF Files") ,
+                                                   parent);
+                QSet<QString> fileNames=result.fileNames.toSet();
+                QString codec=result.encoding;
 
-        int nbFiles=fileNames.count();
-        if (nbFiles) {
+                int nbFiles=fileNames.count();
+                if (nbFiles) {
 
-                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-                {
-                        SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18n("Import %1 with codec %2",
-                                                    (iMode==SKGImportExportManager::CSV || iMode==SKGImportExportManager::CSVUNIT ? i18n("CSV") :
-                                                     iMode==SKGImportExportManager::OFX ? i18n("OFX") : i18n("QIF")), codec), err, nbFiles);
+                        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                        {
+                                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18n("Import %1 with codec %2",
+                                                            (iMode==SKGImportExportManager::CSV || iMode==SKGImportExportManager::CSVUNIT ? i18n("CSV") :
+                                                             iMode==SKGImportExportManager::OFX ? i18n("OFX") : i18n("QIF")), codec), err, nbFiles);
 
-                        if (err.isSucceeded()) err=currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
+                                if (err.isSucceeded()) err=currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
 
-                        QSetIterator<QString> f(fileNames);
-                        int i=1;
-                        while (err.isSucceeded() && f.hasNext()) {
-                                QString fileName=f.next();
-                                SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, iMode, fileName);
-                                imp1.setCodec(codec);
-                                err=imp1.importFile();
-                                if (err.isFailed()) {
-                                        err.addError(ERR_FAIL, i18n("Import of [%1] failed", fileName));
-                                } else {
-                                        err=SKGError(0, i18n("File [%1] successfully imported.", fileName));
+                                QSetIterator<QString> f(fileNames);
+                                int i=1;
+                                while (err.isSucceeded() && f.hasNext()) {
+                                        QString fileName=f.next();
+                                        SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, iMode, fileName);
+                                        imp1.setCodec(codec);
+                                        err=imp1.importFile();
+                                        if (err.isFailed()) {
+                                                err.addError(ERR_FAIL, i18n("Import of [%1] failed", fileName));
+                                        } else {
+                                                err=SKGError(0, i18n("File [%1] successfully imported.", fileName));
+                                        }
+
+                                        if (err.isSucceeded()) err=currentBankDocument->stepForward(i);
+                                        i++;
                                 }
-
-                                if (err.isSucceeded()) err=currentBankDocument->stepForward(i);
-                                i++;
                         }
+                        QApplication::restoreOverrideCursor();
                 }
-                QApplication::restoreOverrideCursor();
-        }
 
-        //status bar
-        if (err.isSucceeded() && nbFiles>1) {
-                err=SKGError(0, i18n("%1 files successfully imported.", nbFiles));
-        }
+                //status bar
+                if (err.isSucceeded() && nbFiles>1) {
+                        err=SKGError(0, i18n("%1 files successfully imported.", nbFiles));
+                }
 
-        //Display error
-        parent->displayErrorMessage(err);
+                //Display error
+                if (parent) parent->displayErrorMessage(err);
+        }
 }
 
 void SKGImportExportPlugin::exportCsv()
@@ -298,7 +312,7 @@ void SKGImportExportPlugin::exportCsv()
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::exportCsv",err);
         QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.csv|"+i18n("CSV Files") , parent);
-        if (fileName.isEmpty()) return;
+        if (fileName.isEmpty() || !currentBankDocument) return;
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         {
@@ -315,7 +329,7 @@ void SKGImportExportPlugin::exportCsv()
         else err.addError(ERR_FAIL, i18n("Export of [%1] failed", fileName));
 
         //Display error
-        parent->displayErrorMessage(err);
+        if (parent) parent->displayErrorMessage(err);
 }
 
 void SKGImportExportPlugin::exportQif()
@@ -323,7 +337,7 @@ void SKGImportExportPlugin::exportQif()
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::exportQif",err);
         QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///IMPEXP"), "*.qif|"+i18n("QIF Files") , parent);
-        if (fileName.isEmpty()) return;
+        if (fileName.isEmpty() || !currentBankDocument) return;
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         {
@@ -340,52 +354,56 @@ void SKGImportExportPlugin::exportQif()
         else err.addError(ERR_FAIL, i18n("Export of [%1] failed", fileName));
 
         //Display error
-        parent->displayErrorMessage(err);
+        if (parent) parent->displayErrorMessage(err);
 }
 
 void SKGImportExportPlugin::foundTransfer()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::foundTransfer",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        int NbOperationsMerged=0;
-        {
-                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Find and group transfers"), err);
-                if (err.isSucceeded()) {
-                        SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
-                        err=imp1.findAndGroupTransfers(NbOperationsMerged);
+        if (currentBankDocument) {
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                int NbOperationsMerged=0;
+                {
+                        SKGBEGINTRANSACTION(*currentBankDocument, i18n("Find and group transfers"), err);
+                        if (err.isSucceeded()) {
+                                SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
+                                err=imp1.findAndGroupTransfers(NbOperationsMerged);
+                        }
                 }
+                QApplication::restoreOverrideCursor();
+
+                //status bar
+                if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully processed. %1 operations merged.", NbOperationsMerged));
+                else err.addError(ERR_FAIL, i18n("Processing failed."));
+
+                //Display error
+                if (parent) parent->displayErrorMessage(err);
         }
-        QApplication::restoreOverrideCursor();
-
-        //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully processed. %1 operations merged.", NbOperationsMerged));
-        else err.addError(ERR_FAIL, i18n("Processing failed."));
-
-        //Display error
-        parent->displayErrorMessage(err);
 }
 
 void SKGImportExportPlugin::cleanBankPerfect()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::cleanBankPerfect",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        {
-                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Clean BankPerfect's imports"), err);
-                if (err.isSucceeded()) {
-                        SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
-                        err=imp1.cleanBankPerfectImport();
+        if (currentBankDocument) {
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                {
+                        SKGBEGINTRANSACTION(*currentBankDocument, i18n("Clean BankPerfect's imports"), err);
+                        if (err.isSucceeded()) {
+                                SKGImportExportManager imp1((SKGDocumentBank*) currentBankDocument, SKGImportExportManager::QIF, "");
+                                err=imp1.cleanBankPerfectImport();
+                        }
                 }
+                QApplication::restoreOverrideCursor();
+
+                //status bar
+                if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully cleaned."));
+                else err.addError(ERR_FAIL, i18n("Clean failed."));
+
+                //Display error
+                if (parent) parent->displayErrorMessage(err);
         }
-        QApplication::restoreOverrideCursor();
-
-        //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully cleaned."));
-        else err.addError(ERR_FAIL, i18n("Clean failed."));
-
-        //Display error
-        parent->displayErrorMessage(err);
 }
 
 void SKGImportExportPlugin::cleanBanks()
@@ -407,6 +425,6 @@ void SKGImportExportPlugin::cleanBanks()
         else err.addError(ERR_FAIL, i18n("Clean failed."));
 
         //Display error
-        parent->displayErrorMessage(err);
+        if (parent) parent->displayErrorMessage(err);
 }
 #include "skgimportexportplugin.moc"
