@@ -64,7 +64,7 @@ void SKGScheduledPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocum
         actionCollection()->addAction( QLatin1String("schedule_operation"), scheduleOperationAction );
         scheduleOperationAction->setShortcut(Qt::CTRL+Qt::Key_I);
 
-        iParent->registedGlobalAction("schedule_operation", scheduleOperationAction);
+        if(parent) parent->registedGlobalAction("schedule_operation", scheduleOperationAction);
 }
 
 void SKGScheduledPlugin::refresh()
@@ -100,7 +100,7 @@ void SKGScheduledPlugin::refresh()
                                 QApplication::restoreOverrideCursor();
                         }
                         //Display error
-                        parent->displayErrorMessage(err);
+                        if(parent) parent->displayErrorMessage(err);
                 }
         }
 }
@@ -204,6 +204,6 @@ void SKGScheduledPlugin::actionScheduleOperation()
         else err.addError(ERR_FAIL, i18n("Operation schedule failed"));
 
         //Display error
-        parent->displayErrorMessage(err);
+        if(parent) parent->displayErrorMessage(err);
 }
 #include "skgscheduledplugin.moc"
