@@ -59,7 +59,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGMainPanel* iParent, SKGDoc
         ui.kView->setDefaultSaveParameters(iDocument, "SKG_DEFAULT_SCHEDULED");
 
         //Add registered global action in contextual menu
-        ui.kView->insertAction(0, iParent->getGlobalAction("edit_delete"));
+        if (iParent) ui.kView->insertAction(0, iParent->getGlobalAction("edit_delete"));
 
         //Add Standard KDE Icons to buttons to Operations
         ui.kModifyBtn->setIcon(KIcon("dialog-ok-apply"));
@@ -126,9 +126,15 @@ void SKGScheduledPluginWidget::setState(const QString& iState )
 
         QSortFilterProxyModel* modelproxy = (QSortFilterProxyModel*) ui.kView->model();
         SKGObjectModel* modelview=(SKGObjectModel*) modelproxy->sourceModel ();
-        modelview->setFilter("1=0");
-        modelview->setFilter("");
-        modelview->refresh();
+        if (modelview) {
+                modelview->setFilter("1=0");
+                modelview->setFilter("");
+                modelview->refresh();
+        }
+
+        //Correction bug 2299394 vvv
+        if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContents();
+        //Correction bug 2299394 ^^^
 }
 
 QWidget* SKGScheduledPluginWidget::getWidgetForPrint()
