@@ -79,14 +79,15 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                 ui.kUnitTableViewEdition->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNIT");
 
                 //Add registered global action in contextual menu
-                ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
-                QAction* sep=new QAction(this);
-                sep->setSeparator(true);
-                ui.kUnitTableViewEdition->insertAction(0, sep);
-                ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_split_stock"));
-                ui.kUnitTableViewEdition->insertAction(0, sep);
-                ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
-
+                if (iParent) {
+                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
+                        QAction* sep=new QAction(this);
+                        sep->setSeparator(true);
+                        ui.kUnitTableViewEdition->insertAction(0, sep);
+                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_split_stock"));
+                        ui.kUnitTableViewEdition->insertAction(0, sep);
+                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
+                }
                 connect(ui.kUnitTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                         this, SLOT(onSelectionChanged()));
 
@@ -105,7 +106,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                 ui.kUnitValueTableViewEdition->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNITVALUE");
 
                 //Add registered global action in contextual menu
-                ui.kUnitValueTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
+                if (iParent) ui.kUnitValueTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
 
                 connect(ui.kUnitValueTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                         this, SLOT(onSelectionValueChanged()));
@@ -130,86 +131,90 @@ void SKGUnitPluginWidget::onSelectionChanged()
         SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionChanged");
         //Mapping
         QItemSelectionModel *selModel=ui.kUnitTableViewEdition->selectionModel();
-        QModelIndexList indexes=selModel->selectedRows();
-        int nbSelect=indexes.count();
-        if (nbSelect) {
-                QModelIndex idx=indexes[indexes.count()-1];
+        if (selModel) {
+                QModelIndexList indexes=selModel->selectedRows();
+                int nbSelect=indexes.count();
+                if (nbSelect) {
+                        QModelIndex idx=indexes[indexes.count()-1];
 
-                QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kUnitTableViewEdition->model();
-                QModelIndex idxs=proxyModel->mapToSource(idx);
+                        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kUnitTableViewEdition->model();
+                        QModelIndex idxs=proxyModel->mapToSource(idx);
 
-                SKGUnitObject unit(objectModel->getObject(idxs));
+                        SKGUnitObject unit(objectModel->getObject(idxs));
 
-                ui.kNameCreatorUnit->setText(unit.getAttribute("t_name"));
-                ui.kSymbolCreatorUnit->setText(unit.getAttribute("t_symbol"));
-                ui.kCountryCreatorUnit->setText(unit.getAttribute("t_country"));
+                        ui.kNameCreatorUnit->setText(unit.getAttribute("t_name"));
+                        ui.kSymbolCreatorUnit->setText(unit.getAttribute("t_symbol"));
+                        ui.kCountryCreatorUnit->setText(unit.getAttribute("t_country"));
 
-                QString val=unit.getAttribute("t_type");
-                if (val=="1") val=i18n("Primary currency");
-                else if (val=="2") val=i18n("Secondary currency");
-                else if (val=="C") val=i18n("Currency");
-                else if (val=="S") val=i18n("Share");
-                else if (val=="I") val=i18n("Index");
-                else val=i18n("Object");
-                ui.kTypeCreatorUnit->setText(val);
-                ui.kInternetCreatorUnit->setText(unit.getAttribute("t_internet_code"));
-                ui.kUnitCreatorUnit->setText(unit.getAttribute("t_UNIT"));
-        } else {
-                ui.kNameCreatorUnit->setText("");
-                ui.kSymbolCreatorUnit->setText("");
-                ui.kCountryCreatorUnit->setText("");
-                ui.kInternetCreatorUnit->setText("");
-                ui.kUnitCreatorUnit->setText("");
-        }
-
-        ui.kUnitValueFrame->setEnabled(nbSelect==1);
-        ui.kNameCreatorUnit->setEnabled(nbSelect<=1);
-        ui.kSymbolCreatorUnit->setEnabled(nbSelect<=1);
-        ui.kInternetCreatorUnit->setEnabled(nbSelect<=1);
-        ui.kUnitValueDownload->setEnabled(nbSelect>0);
-
-        //Fill values
-        SKGObjectModel* objectModel =(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
-        objectModel->setFilter(""); //Correction 2299600: to be sure that refresh will be done
-        objectModel->setFilter("rd_unit_id=(select id from unit where t_name='"+SKGServices::stringToSqlString(ui.kNameCreatorUnit->text())+"') order by d_date desc");
-        objectModel->refresh();
-
-        ui.kUnitOfUnitLbl->setText(ui.kUnitCreatorUnit->text());
-
-        //Draw plot
-        ui.kplotwidget->removeAllPlotObjects();
-
-        if (nbSelect==1) {
-                KPlotObject *kpo = new KPlotObject( Qt::red, KPlotObject::Lines );
-                double xMin=99999999;
-                double xMax=0;
-                double yMax=0;
-                int nb=objectModel->rowCount(QModelIndex());
-                ui.kplotwidget->setEnabled(nb>1);
-                for (int i=0; i<nb; ++i) {
-                        QDate date=objectModel->data(objectModel->index(i,0), Qt::UserRole).toDate();
-                        int x=date.toJulianDay();
-                        double y=objectModel->data(objectModel->index(i,1), Qt::UserRole).toDouble();
-                        kpo->addPoint(x, y/*, date.toString(Qt::DefaultLocaleShortDate)*/);
-
-                        xMin=(x<xMin ? x : xMin);
-                        xMax=(x>xMax ? x : xMax);
-                        yMax=(y>yMax ? y : yMax);
+                        QString val=unit.getAttribute("t_type");
+                        if (val=="1") val=i18n("Primary currency");
+                        else if (val=="2") val=i18n("Secondary currency");
+                        else if (val=="C") val=i18n("Currency");
+                        else if (val=="S") val=i18n("Share");
+                        else if (val=="I") val=i18n("Index");
+                        else val=i18n("Object");
+                        ui.kTypeCreatorUnit->setText(val);
+                        ui.kInternetCreatorUnit->setText(unit.getAttribute("t_internet_code"));
+                        ui.kUnitCreatorUnit->setText(unit.getAttribute("t_UNIT"));
+                } else {
+                        ui.kNameCreatorUnit->setText("");
+                        ui.kSymbolCreatorUnit->setText("");
+                        ui.kCountryCreatorUnit->setText("");
+                        ui.kInternetCreatorUnit->setText("");
+                        ui.kUnitCreatorUnit->setText("");
                 }
-                ui.kplotwidget->setLimits( xMin, xMax, 0, yMax);
-                ui.kplotwidget->addPlotObject( kpo );
-                ui.kplotwidget->setAntialiasing (true);
 
-                KPlotAxis* axis=ui.kplotwidget->axis(KPlotWidget::BottomAxis);
-                axis->setTickLabelsShown (false);
+                ui.kUnitValueFrame->setEnabled(nbSelect==1);
+                ui.kNameCreatorUnit->setEnabled(nbSelect<=1);
+                ui.kSymbolCreatorUnit->setEnabled(nbSelect<=1);
+                ui.kInternetCreatorUnit->setEnabled(nbSelect<=1);
+                ui.kUnitValueDownload->setEnabled(nbSelect>0);
+
+                //Fill values
+                SKGObjectModel* objectModel =(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
+                if (objectModel) {
+                        objectModel->setFilter(""); //Correction 2299600: to be sure that refresh will be done
+                        objectModel->setFilter("rd_unit_id=(select id from unit where t_name='"+SKGServices::stringToSqlString(ui.kNameCreatorUnit->text())+"') order by d_date desc");
+                        objectModel->refresh();
+                }
+
+                ui.kUnitOfUnitLbl->setText(ui.kUnitCreatorUnit->text());
+
+                //Draw plot
+                ui.kplotwidget->removeAllPlotObjects();
+
+                if (nbSelect==1 && objectModel) {
+                        KPlotObject *kpo = new KPlotObject( Qt::red, KPlotObject::Lines );
+                        double xMin=99999999;
+                        double xMax=0;
+                        double yMax=0;
+                        int nb=objectModel->rowCount(QModelIndex());
+                        ui.kplotwidget->setEnabled(nb>1);
+                        for (int i=0; i<nb; ++i) {
+                                QDate date=objectModel->data(objectModel->index(i,0), Qt::UserRole).toDate();
+                                int x=date.toJulianDay();
+                                double y=objectModel->data(objectModel->index(i,1), Qt::UserRole).toDouble();
+                                kpo->addPoint(x, y/*, date.toString(Qt::DefaultLocaleShortDate)*/);
+
+                                xMin=(x<xMin ? x : xMin);
+                                xMax=(x>xMax ? x : xMax);
+                                yMax=(y>yMax ? y : yMax);
+                        }
+                        ui.kplotwidget->setLimits( xMin, xMax, 0, yMax);
+                        ui.kplotwidget->addPlotObject( kpo );
+                        ui.kplotwidget->setAntialiasing (true);
+
+                        KPlotAxis* axis=ui.kplotwidget->axis(KPlotWidget::BottomAxis);
+                        axis->setTickLabelsShown (false);
+                }
+
+                //Correction bug 2299394 vvv
+                if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
+                //Correction bug 2299394 ^^^
+
+                onUnitCreatorModified();
+                emit selectionChanged();
         }
-
-        //Correction bug 2299394 vvv
-        if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
-        //Correction bug 2299394 ^^^
-
-        onUnitCreatorModified();
-        emit selectionChanged();
 }
 
 void SKGUnitPluginWidget::onSelectionValueChanged()
@@ -217,21 +222,25 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
         SKGTRACEIN(10, "SKGUnitPluginWidget::onSelectionValueChanged");
         //Mapping
         QItemSelectionModel *selModel=ui.kUnitValueTableViewEdition->selectionModel();
-        QModelIndexList indexes=selModel->selectedRows();
-        int nbSelect=indexes.count();
-        if (nbSelect) {
-                QModelIndex idx=indexes[indexes.count()-1];
+        if (selModel) {
+                QModelIndexList indexes=selModel->selectedRows();
+                int nbSelect=indexes.count();
+                if (nbSelect) {
+                        QModelIndex idx=indexes[indexes.count()-1];
 
-                SKGObjectModel* model=(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
-                SKGUnitValueObject unit(model->getObject(idx));
+                        SKGObjectModel* model=(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
+                        if (model) {
+                                SKGUnitValueObject unit(model->getObject(idx));
 
-                ui.kDateEdit->setDate(SKGServices::stringToTime(unit.getAttribute("d_date")).date());
-                ui.kAmountEdit->setText(unit.getAttribute("f_quantity"));
-        } else {
-                ui.kDateEdit->setDate(QDate::currentDate());
-                ui.kAmountEdit->setText("");
+                                ui.kDateEdit->setDate(SKGServices::stringToTime(unit.getAttribute("d_date")).date());
+                                ui.kAmountEdit->setText(unit.getAttribute("f_quantity"));
+                        }
+                } else {
+                        ui.kDateEdit->setDate(QDate::currentDate());
+                        ui.kAmountEdit->setText("");
+                }
+                emit selectionChanged();
         }
-        emit selectionChanged();
 }
 
 void SKGUnitPluginWidget::onUnitCreatorModified()
@@ -420,7 +429,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
         QString unitname=iUnit.getName();
         QString code=iUnit.getInternetCode();
         SKGDocumentBank* doc=(SKGDocumentBank*) iUnit.getDocument();
-        if (!code.isEmpty()) {
+        if (!code.isEmpty() && doc) {
                 bool invert=code.contains(" /");
                 code.remove(" /");
                 QString unitRef=doc->getPrimaryUnit();
@@ -618,7 +627,7 @@ SKGObjectBase::SKGListSKGObjectBase SKGUnitPluginWidget::getSelectedObjects()
                 //Selection on unit values
                 QItemSelectionModel *selModel=ui.kUnitValueTableViewEdition->selectionModel();
                 SKGObjectModel* model=(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
-                if (model) {
+                if (model && selModel) {
                         QModelIndexList indexes=selModel->selectedRows();
                         foreach(const QModelIndex& index, indexes) {
                                 SKGObjectBase obj=model->getObject(index);
@@ -684,9 +693,11 @@ void SKGUnitPluginWidget::setState(const QString& iState )
 
         QSortFilterProxyModel* modelproxy = (QSortFilterProxyModel*) ui.kUnitTableViewEdition->model();
         SKGObjectModel* modelview=(SKGObjectModel*) modelproxy->sourceModel ();
-        modelview->setFilter("1=0");
-        modelview->setFilter("");
-        modelview->refresh();
+        if (modelview) {
+                modelview->setFilter("1=0");
+                modelview->setFilter("");
+                modelview->refresh();
+        }
 }
 
 void SKGUnitPluginWidget::refresh()
